/*==============================================================================
Project:      VAT refunds and firms' performance: Evidence from a withholding 
		      reform in Honduras             
Code authors: Thiago Scot, Jose Carlo Bermúdez, and Monica Mogollón                                       
--------------------------------------------------------------------------------
Updated:	   September, 2024
==============================================================================*/

	clear all
	set more off
	set varabbrev off
	cap program drop _all 

	* Start timer
	timer clear 1
	timer clear 2
	timer on 1	

	/*******************************************************************************	
					Set working paths
*******************************************************************************/


		global path		    "C:\WBG\github\208"
		global do 		"C:\WBG\github\208\Code\ISV_Devoluciones"

	
	
	sysdir set PLUS "${do}\ado"
set varabbrev on
/*******************************************************************************	
					Packages required for estimations
*******************************************************************************/

	global packs_ssc "estout reghdfe ftools erepost egenmore cdfplot coefplot wbopendata gtools cic outreg2 outreg winsor2"	
	
	foreach p of global packs_ssc {
		cap which `p'
		if (_rc) { 
			dis in red "Package `p' not found. Installing it..."
			ssc install `p'
		}
	}
	
	
/*******************************************************************************
							Running do files
*******************************************************************************/

*------------------------ Set globals & Programs -------------------------------*
	do "$do/0a_Globals.do"														// Globals with working paths and instructions
	do "$do/0b_Prepare_Programs.do"											    // Prepare functions for actions that tend to repeat several times in empirical analysis

	
*-------------------- Clean Databases and create variables ---------------------*
	do "$do/1a_Clean_Databases.do"					    						// Clean original shared data (2011-2019)
	do "$do/1b_Create_ISV_panelvars.do"			    						    // Create ISV variables 
	do "$do/1c_Clean_ISRPJ.do"													// Clean Corporate yearly tax data to match with sales tax
	do "$do/1d_Clean_ISRPN.do"													// Clean non-incorporated firms yearly tax data to match with sales tax


*---------------------- Descriptive Section : VAT refunds ----------------------*
	do "$do/3a_Descriptives_ISV.do"			  									// Descriptives all periods
	do "$do/3b_Descriptives_CrossCountry_Refunds.do" 							// Figures with cross-country (TADAT & B-Ready) data


*------------------------- Analysis of the Reform ------------------------------*
	
	* Preparing working datasets for analysis
	do "$do/4a_PrepareBalancedDefinition.do"									// Prepare definition of balancedness, including ISR filing
	do "$do/4b_PreparePanelReform_treat.do"										// Define treatment/control variables for all samples
	do "$do/4c_PrepareTime_Invariant.do"										// Prepare true income and time-invariant variables for later heterogeneity analysis
	do "$do/4d_Prepare_Sales_Shares.do"											// Prepare the share of quarterly/monthly sales in the year
	do "$do/4e_PreparePanelReform_ISV.do"										// Prepare panel with all balancedness and treatment indicators using VAT (ISV) records
	do "$do/4e_PreparePanelReform_ISR.do"										// Prepare panel with all balancedness and treatment indicators using income tax (ISR) records
	
	* Descriptive Analysis 
	do "$do/5a_Descriptives_Reform_Figures.do"									// Figures related to the reform
	do "$do/5b_Descriptives_SERaggregates.do"									// Figure comparing DCC amounts reported by taxpayers and DCC providers
	do "$do/5c_Descriptives_Reform_Table.do"									// Produces summary statistics for firms included in the analysis of the reform
	
	timer on 2
	
	* Baseline Empirical Analysis
	do "$do/6a_Analysis_Reform_ISV.do"											// Create Table and graphs for the reform (ISV collapsed at quarter level)
	do "$do/6a_Analysis_Reform_ISR.do"											// Create tables and graphs analyzing the impact of the reform on firms' performance
	
	* Robustness for baseline estimates
	do "$do/6b_Robustness_ISV.do"												// Robustness for baseline VAT outcomes with different sample balancedness & Winsor thresholds
	do "$do/6b_Robustness_ISR.do"												// Robustness for baseline firms' performance outcomes with different sample balancedness & Winsor thresholds
	
	* Robustness changing treatment/control 
	do "$do/6c_Robustness_ISV_Treat.do"											// Robustness for VAT outcomes using alternative definition of treatment and control groups
	do "$do/6c_Robustness_ISR_Treat.do"											// Robustness on firms' performance using alternative definition of treatment and control groups
	
	* Heterogeneity Analysis
	do "$do/6d_Heterogeneity_ISV.do"											// Conduct heterogeneity analysis on VAT outcomes
	do "$do/6d_Heterogeneity_ISR.do"											// Conduct heterogeneity analysis on firms' performance
	
	timer off 2
	
	
*----------------------------- Finish timer ------------------------------------*	
	qui{
		timer off 1
		
		timer list 1
		local minutes1 = round(`r(t1)'/60)
		
		timer list 2
		local minutes2 = round(`r(t2)'/60)
	}
	
	dis in red "Empirical analysis took `minutes2' minutes to be run. The entire code took `minutes1' minutes to be run." 			        
