/*=============================================================================
Name: 		 1b_Create_ISV_panelvars.do	

Description: This do-file takes processed de-identified VAT records, harmonizes 
			 them, and creates an intermediate dataset for further analysis.

Input: 	     ISV_panel.dta

Output: 	 ISV_panel_vars.dta
==============================================================================*/


use "$databases/ISV_panel.dta", clear

sort id year month
tsset id month
drop if id == 51131 															// outlier

rename (ventas_gravadas totaldebitofiscalper totalcreditofiscalper ///
	saldodefinitivofavorfisco imptoretevtastarjetas ///
	imptoretenidovtasestado imptoretenidoxacuerdo215_2010 imptoretelineasaereas saldofavorperiodoant creditofiscalfavorcontr) ///
	(taxable_sales gross_liability credits net_payment withholding_cards  withholding_govt ///
	withholding_large  withholding_airlines unrefunded_balance_prev unrefunded_balance_end)

	
*Tag firms with zero taxable sales & zero credits in every period 
	gegen ventas_max = max(taxable_sales), by(id)
	gegen credit_max = max(credits), by(id)
	gen never_taxable_credits = (ventas_max == 0 & credit_max == 0)


* Create variables
	bys id: gen number_declarations = _N											
	bys id: gen number_declarations_unique = number_declarations if _n == 1	
		
	gen dummy_with_cards = (withholding_cards>0 & withholding_cards != .)
	gen dummy_with_cards_n = 1 if (dummy_with_cards == 1)

	gegen max_tarj = max(dummy_with_cards_n), by(id year)
	bys id year: replace max_tarj = . if _n != 1

	gen withholding_cards_positive = withholding_cards if dummy_with_cards == 1
	gen share_withheld = withholding_cards/gross_liability	
	gen net_liability = subtotalfavorfisco - subtotalfavorcontrib
	
	egen taxable_purchases  = rowtotal(comprasnetasmerc12 comprasnetasmerc15 comprasnetasmerc18)
	egen exempted_purchases = rowtotal(comprasexentasmerc12 comprasexentasmerc15 comprasexentasmerc18 ///
							           compras_exoneradas_oce_15 compras_exoneradas_oce_18)						  
	egen imports 		    = rowtotal(adquisi_fyduca_gravadas_15 adquisi_fyduca_gravadas_18 adquisi_fyduca_exe_exo_15 adquisi_fyduca_exe_exo_18 ///
								   importgrav12 importgrav15 importgrav18 importregion12 importregion15 importregion18  ///
							       importacionesexentas12 importacionesexentas15 importacionesexentas18)
	egen total_purchases = rowtotal(taxable_purchases exempted_purchases imports)
	
	egen exempted_sales = rowtotal(ventas_exentas ventas_oce)
	egen total_revenue  = rowtotal(taxable_sales ventas_exentas ventas_oce exportaciones fyduca)

	egen total_withholding = rowtotal(withholding_govt ///
									withholding_large withholding_cards ///
									withholding_airlines)
									
	egen total_anticipated = rowtotal( importerecibosoficpagoper importecompensarperiodo1 importecompensarperiodo2)
								
	gen withheld_any = (total_withholding>0 & total_withholding != .)
	gen exports = exportaciones
	gen dummy_sell_oce = (ventas_oce > 0 & ventas_oce != .)
	egen purchases_oce  = rowtotal(compras_exoneradas_oce_15 compras_exoneradas_oce_18) 
	gen dummy_buy_oce = (purchases_oce > 0 & purchases_oce != .)
								
	foreach var of varlist taxable_sales gross_liability credits net_payment withholding_cards ///
		 withholding_govt withholding_large  net_liability total_withholding total_anticipated ///
		 unrefunded_balance_prev unrefunded_balance_end total_revenue exports exempted_sales ///
		 taxable_purchases exempted_purchases imports total_purchases {
		gen `var'_th = `var'/1000 if 	`var' != .
	}
	

* Some firms do not file end of period unrefunded credit correctly, but we can infer that and correct. 
	sort id month
	gen check_end = F.unrefunded_balance_prev_th								
	gen d = round(unrefunded_balance_end_th,3) == round(check_end,3)	
	tab d if  check_end!=.

	gen check2 = unrefunded_balance_prev_th + (total_withholding_th - net_liability_th)
	gen d2 =  round(check2,3) == round(check_end,3)
	tab d2 if d == 0 & check_end!=.

	gen unrefunded_balance_end_th_corr = unrefunded_balance_end_th
	replace unrefunded_balance_end_th_corr = check_end if (d == 0 & d2 == 1)

	gen positive_balance 		= (unrefunded_balance_end_th_corr > 0 & unrefunded_balance_end_th_corr != .)
	gen flow_balance     		= (unrefunded_balance_end_th_corr - unrefunded_balance_prev_th)
	gen positive_flow_balance 	= (flow_balance > 0 & flow_balance!=.)
	gen share_balance			= unrefunded_balance_end_th_corr/gross_liability_th

	sort id month
	gen month_12 = month(date)
	gen change_balance = unrefunded_balance_prev_th - L12.unrefunded_balance_prev_th
	gen change_balance_year = change_balance if (month_12 == 12)
	gen endyear_balance = unrefunded_balance_prev_th if month_12 == 12


* Label for variables	
gen unit = 1
bys id year: gen unique_firm = 1 if _n == 1

lab var total_revenue_th					"Total revenue (L1,000s)"
lab var taxable_sales_th 					"Taxable Sales (L1,000s)"
lab var exempted_sales_th					"Exempt sales (L1,000s)"
lab var gross_liability_th					"VAT liability (L1,000s)"
lab var credits_th							"VAT credits (L1,000s)"
lab var net_liability_th					"Net VAT liability (L1,000s)"
lab var unrefunded_balance_prev_th 			"Initial balance against TA (L1,000s)"
lab var total_withholding_th				"Total withholding (L1,000s)"
lab var total_anticipated_th				"Total anticipated payments (L1,000s)"
lab var net_payment_th 						"Net due VAT payment (L1,000s)"
lab var unrefunded_balance_end_th_corr		"End of period balance against TA (L1,000s)"
lab var positive_balance					"Positive balance agains TA (\%)"
lab var flow_balance						"Change in balance against TA (L1,000s)"
lab var positive_flow_balance				"Balance against TA increased in period (\%)"
lab var dummy_with_cards					"Positive DPP witholding claim (\%)"
lab var withheld_any						"Positive any witholding claim (\%)"
lab var withholding_cards_th				"DPP witholding (L1,000s)"
lab var	withholding_govt_th					"Sales to government withholding (L1,000s)" 
lab var withholding_large_th				"Large firms withholding (L1,000s)"
lab var max_tarj							"Unique firms reporting DPP witholding"
lab var dummy_with_cards_n	 				"Observations reporting DPP witholding"
lab var share_withheld						"DPP witholding as \% of taxes owed"
lab var share_balance						"Balance against TA as share of VAT liability"
lab var endyear_balance						"Balance unrefunded credits in December (L1,000s)"
lab var change_balance_year					"Yearlychange in unrefunded credits balance (L1,000s)"
lab var exports_th							"Total exports (L1,000s)"
lab var dummy_sell_oce 						"Firms sells to exporters (OCE)"
lab var dummy_buy_oce						"Exporters purchases using OCE"
lab var taxable_purchases_th				"Taxable purchases (L 1,000s)"
lab var exempted_purchases_th 				"Exempt purchases (L 1,000s)"
lab var imports_th 							"Imports  (L 1,000s)"
lab var total_purchases_th					"Total purchases (L 1,000s)"

keep id date month year ventas_max-unique_firm
order id year month date total_revenue_th taxable_sales_th exempted_sales_th taxable_purchases_th gross_liability_th credits_th net_liability_th ///
	  total_withholding_th unrefunded_balance_prev_th net_payment_th unrefunded_balance_end_th withholding_cards_th withholding_govt_th ///
	  withholding_large_th dummy_with_cards share_withheld withholding_cards_th withholding_govt_th withholding_large_th exempted_purchases_th imports_th total_purchases_th
save "$databases/ISV_panel_vars.dta", replace

