/*=============================================================================
Name: 		 1c_Clean_ISRPJ.do

Description: This do-file raw de-identified dataset from corporate income tax data, 
			 clean, harmonize, and build balance sheet outcomes. The output is ready 
			 for analysis.

Input: 	     Base_IM_ATC_CGIT_IT_AE1.dta

Output: 	 ISRPJ_workingdatabase.dta
==============================================================================*/


use "$rawdata/Base_IM_ATC_CGIT_IT_AE1.dta", clear
drop impuestodesc impuestoomisos formulariodesc periododeclaracion impuestoid
drop if _merge != 3 & !missing(_merge)

* Brief replacement
drop cyg_arrendamientos_c							
gen cyg_arrendamientos_c = CYG_ARRENDAMIENTOS_C

gen double resultado_ejercicio = total_ingresos_resul_ejercicio - total_deduc_del_ejerc  //LUCRO
label var resultado_ejercicio "Resultado del ejercicio"


**** Creating taxable income from gross revenue and deductions *****

* pre-tax profits
gen double precio_trans_ing = ingreautoajustepreciostran + ingrajustespreciostransf
replace precio_trans_ing = 0 if (abs(ingreautoajustepreciostran - ingrajustespreciostransf)<1 & ingreautoajustepreciostran!=0)
gen double precio_trans_ded = deducautoajustepreciostran + cygajustespreciostranfc
replace precio_trans_ded = 0 if  (abs(deducautoajustepreciostran - cygajustespreciostranfc)<1 & deducautoajustepreciostran!=0)

gen double deductions_total = total_deduc_del_ejerc - arrastperdidaart20 - ctmontobeneficio + precio_trans_ing + precio_trans_ded + perdidaporactiart20

gen double base_imp_renta = (resultado_ejercicio - arrastperdidaart20 - ctmontobeneficio + precio_trans_ing + precio_trans_ded + perdidaporactiart20)

gen taxable_income = base_imp_renta
replace taxable_income=0 if taxable_income<=0

replace base_imp_renta = 0 if base_imp_renta<=0
replace base_imp_renta = resultadodelejercicio if (year == 2011) & abs(baseimponrtanetagrav - base_imp_renta)>1


* Variable of due taxes
gen double imp_segun_tarifa_renta_alt = 0.25*baseimponrtanetagrav						
gen double  profit_rate_imponible 	  = baseimponrtanetagrav/total_ingresos_resul_ejercicio		
gen double  taxable_inc_rate      	  = taxable_income/total_ingresos_resul_ejercicio

*Minimum Tax
gen porcentaje_ing_brutos_correct = porcentaje_ing_brutos
replace porcentaje_ing_brutos_correct = 0 if year == 2013
replace porcentaje_ing_brutos_correct = 0 if baseimponrtanetagrav <=0 

gen max_ISR_IM = max(porcentaje_ing_brutos_correct,imp_segun_tarifa_renta_alt)	//Maximum between (MinimumTax, LinearIncomeTax)
gen max_AS = max_ISR_IM + imp_segun_tarifa_aport_solid							//Add solidarity tax

*Variable indicating which of the taxes is "binding"
gen causa_impuesto = .
replace causa_impuesto = 0 if max(max_AS, imp_segun_tarifa_activo_neto) == 0
replace causa_impuesto = 1 if max(max_AS, imp_segun_tarifa_activo_neto) == max_AS & ///
	max(porcentaje_ing_brutos_correct,imp_segun_tarifa_renta_alt) == imp_segun_tarifa_renta_alt	& ///
	max(max_AS, imp_segun_tarifa_activo_neto) > 0
replace causa_impuesto = 2 if max(max_AS, imp_segun_tarifa_activo_neto) == imp_segun_tarifa_activo_neto & ///
	max(max_AS, imp_segun_tarifa_activo_neto) > 0
replace causa_impuesto = 3 if max(max_AS, imp_segun_tarifa_activo_neto) == max_AS & ///
	max(porcentaje_ing_brutos_correct,imp_segun_tarifa_renta_alt) == porcentaje_ing_brutos_correct & ///
   	max(max_AS, imp_segun_tarifa_activo_neto) > 0  
lab def causa_impuesto 0"Ninguno" 1"Renta" 2"Activo Neto" 3"Impuesto Mínimo"
lab val causa_impuesto causa_impuesto

tab causa_impuesto, gen(causa_impuesto_)

gen double impuesto_causado = .
replace impuesto_causado = 0 		 						if causa_impuesto == 0
replace impuesto_causado = max_AS 							if causa_impuesto == 1
replace impuesto_causado = imp_segun_tarifa_activo_neto 	if causa_impuesto == 2
replace impuesto_causado = max_AS 							if causa_impuesto == 3
label var impuesto_causado "Impuesto causado real"


* Drop exempt firms
egen cre_importe_exo = rowtotal (cre_importe_exo_red_rta cre_importe_exo_red_act_neto cre_importe_exo_aport_soli), missing

gen ratio_exoneracion = 0
replace ratio_exoneracion = (cre_importe_exo_red_rta + cre_importe_exo_aport_soli)/(imp_segun_tarifa_renta + ///
	imp_segun_tarifa_aport_solid) if (causa_impuesto==1 | causa_impuesto==3) 
replace ratio_exoneracion = cre_importe_exo_red_act_neto/imp_segun_tarifa_activo_neto if causa_impuesto==2	

gen exonerado = (ratio_exoneracion > 0.9 & !missing(ratio_exoneracion))
drop cre_importe_exo
drop if exonerado == 1

*Correct income and create new vars
replace impuesto_causado = max_AS - imp_segun_tarifa_aport_solid if (causa_impuesto == 1 | causa_impuesto == 3) & regimenespecial == "RIT"

* Pre-tax and After-tax profits
gen double pre_tax_profits 	 = resultado_ejercicio
gen double after_tax_profits = pre_tax_profits - impuesto_causado

* Scale outcomes in million Lempiras
gen receita_mil = total_ingresos_resul_ejercicio/1000000					
gen total_gross_revenue_mil = total_ingresos_resul_ejercicio/1000000		
gen deduction_mil =  deductions_total/1000000								
gen taxable_mil = taxable_income/1000000									
gen impuesto_mil = impuesto_causado/1000000
gen pre_tax_profits_mil = pre_tax_profits/1000000
gen after_tax_profits_mil = after_tax_profits/1000000				

***Grouping cost variables****
egen double labor_costs = rowtotal(cyg_mano_obra_dir_c  cyg_mano_obra_indir_c  cyg_gastos_com_vtas_g cyg_gastos_com_vtas_c ///
cyg_sueldos_salarios_g cyg_sueldos_salarios_c cyg_honorarios_prof_g cyg_cyg_honorarios_extranj_g ///
cyg_honorarios_prof_c cyg_honorarios_extranj_c)
egen double labor_nd = rowtotal(cyg_sueldos_salarios_vnd cyg_honorarios_prof_vnd ///
 cyg_honorarios_extranj_vnd cyg_cyg_gastos_com_vtas_vnd)
gen double net_labor = labor_costs - labor_nd

egen double goods = rowtotal(cyg_inv_inicial_bienes_c cyg_compras_brutas_local_c cyg_compras_import_bienes_c ///
 cyg_inv_inicial_mat_prima_c  cyg_compras_netas_mat_prima_c  cyg_importacion_mat_prima_c ///
 cyg_gastos_indir_fabr_c  cyg_inv_inicial_prod_proc_c cyg_inv_inicial_prod_term_c cyg_gastos_compra_c cyg_gastos_compra_g)
egen double goods_nd = rowtotal(cyg_desc_dev_compras_c  cyg_inv_final_bienes_c cyg_inv_final_mat_prima_c ///
cyg_inv_final_prod_proc_c cyg_inv_final_prod_term_c cyg_gastos_compra_vnd)
gen double net_goods = goods - goods_nd

egen double operations = rowtotal(cyg_mantenimiento_rep_c  cyg_combustibles_lubric_c cyg_arrendamientos_c ///
 cyg_publicidad_propaganda_c cyg_suministros_mat_c cyg_transporte_c cyg_gastos_ind_asig_ext_c cyg_gastos_g_imp_c ///
 cyg_gastos_viaje_c cyg_gastos_representacion_c cyg_servicios_publicos_c cyg_pagos_otros_servicios_c ///
 cyg_pagos_otros_bienes_c cyg_isv_carga_costo_c  ///
 cyg_arrendamientos_g cyg_mantenimiento_rep_g  cyg_combustibles_lubric_g cyg_publicidad_propaganda_g ///
 cyg_suministros_mat_g cyg_transporte_g cyg_gastos_ind_asig_ext_g cyg_gastos_g_imp_g cyg_gastos_viaje_g ///
 cyg_gastos_representacion_g cyg_servicios_publicos_g cyg_pagos_otros_servicios_g cyg_pagos_otros_bienes_g ///
 cyg_isv_carga_costo_g cyg_beneficios_sociales_g cyg_capacitacion_g cyg_informatica_g cyg_gastos_seguro_g ///
 cyg_gastos_vigilancia_g cyg_gastos_años_ant_g cyg_producto_financiero_g)
egen double operations_nd = rowtotal(cyg_arrendamientos_vnd cyg_mantenimiento_rep_vnd  ///
 cyg_combustibles_lubric_vnd cyg_publicidad_propaganda_vnd cyg_suministros_mat_vnd cyg_transporte_vnd cyg_gastos_ind_asig_ext_vnd ///
 cyg_gastos_g_imp_vnd cyg_gastos_viaje_vnd cyg_gastos_representacion_vnd cyg_servicios_publicos_vnd cyg_pagos_otros_servicios_vnd ///
 cyg_pagos_otros_bienes_vnd cyg_isv_carga_costo_vnd cyg_beneficios_sociales_vnd cyg_capacitacion_vnd ///
 cyg_informatica_vnd cyg_gastos_seguro_vnd cyg_gastos_vigilancia_vnd cyg_gastos_años_ant_vnd cyg_producto_financiero_vnd)
gen double net_operations = operations - operations_nd

egen double financial = rowtotal(intereses_banc_local intereses_banc_exterior intereses_terc_local_er ///
 intereses_terc_exterior_er intereses_terc_local_enr intereses_terc_exterior_enr ///
 local_int_bancarios_int delext_bancarios_int local_empresas_rel_int delext_empresas_rel_int ///
 local_empresas_no_rel_int delext_empresas_norel_int)
egen double financial_nd = rowtotal(cyg_inter_banc_local_vnd cyg_inter_banc_exterior_vnd cyg_inter_pag_ter_local_vnd ///
 cyg_inter_pag_ter_ext_er_vnd cyg_inter_pag_ter_localenr_vnd cyg_inter_pag_ter_ext_enr_vnd)
gen double net_financial = financial - financial_nd

egen double losses_others = rowtotal(cyg_inventarios_c cyg_arrend_local_c cyg_arrend_exterior_c cyg_comisiones_local_c ///
cyg_comisiones_exterior_c cyg_otras_peridas_c cyg_seguros_reaseguros_c cyg_depreciacion_aceler_c cyg_depreciacion_noacel_c ///
 cyg_depreciacion_rev_pro_c cyg_agot_activos_expl_c cyg_otras_amortizaciones_c cyg_perd_medicion_c cyg_otros_costos_gastos_c ///
 cyg_otros_costos_gastos_g cyg_cuentas_cobrar_g cyg_inventarios_g cyg_arrend_local_g cyg_arrend_exterior_g ///
 cyg_comisiones_local_g delext_comisiones_int cyg_perdida_vtas_act_rel_g cyg_perdida_vtas_act_norel_g cyg_otras_peridas_g ///
 cyg_seguros_reaseguros_g cyg_depreciacion_aceler_g cyg_depreciacion_noacel_g cyg_depreciacion_rev_pro_g ///
 cyg_agot_activos_expl_g cyg_otras_amortizaciones_g cyg_gnd_reparar_daños_nat_g cyg_inversiones_g cyg_gast_personales_g cyg_sueldos_obsequios_grat_g ///
 cyg_int_cap_invertidos_g cyg_perd_capital_inv_g cyg_contr_especial_seg_pob_g cyg_multas_recargos_g ///
 cyg_doc_no_cumplen_ley_g cyg_impt_rj_an_ap_g cyg_otros_gasto_no_deduc_g cyg_gastos_otras_prov_g cyg_perd_medicion_g ///
 precio_trans_ing  precio_trans_ded  perdidaporactiart20)
egen double losses_others_nd = rowtotal(cyg_cuentas_cobrar_vnd cyg_inventarios_vnd cyg_arrend_local_vnd cyg_arrend_exterior_vnd /// 
 cyg_comisiones_local_vnd cyg_comisiones_exterior_vnd cyg_perdida_vtas_act_rel_vnd cyg_perdida_vtas_act_norel_vnd cyg_otras_peridas_vnd ///
 cyg_seguros_reaseguros_vnd cyg_depreciacion_aceler_vnd cyg_depreciacion_noacel_vnd cyg_depreciacion_rev_pro_vnd ///
 cyg_agot_activos_expl_vnd cyg_otras_amortizaciones_vnd cyg_gast_reparar_daños_nat_vnd cyg_inversiones_vnd cyg_cyg_gast_personales_vnd ///
 cyg_sueldos_obsequios_grat_vnd cyg_int_cap_invertidos_vnd cyg_perd_capital_inv_vnd cyg_contr_especial_seg_pob_vnd ///
 cyg_multas_recargos_vnd cyg_doc_no_cumplen_ley_vnd cyg_impt_rj_an_ap_vnd cyg_otros_gasto_no_deduc_vnd ///
 cyg_gastos_otras_prov_vnd cyg_perd_medicion_vnd arrastperdidaart20 ctmontobeneficio)
gen double net_losses_others = losses_others - losses_others_nd
 
egen double total_sum_deductions = rowtotal(net_labor net_goods net_operations net_financial net_losses_others)
gen match = abs(total_sum_deductions -deductions_total)<10

gen labor_costs_mil=labor_costs/1000000
gen labor_nd_mil = labor_nd/1000000
gen net_labor_mil=net_labor/1000000



/*---------Assets-----------------------------------------------------------------*/

* Procedure of assets to recover correct asset base
	egen double total_assets_c121 = rowtotal(c121_efectivo_equivalent_efect c121_inversiones_corrientes c121_cuentas_docu_porcobrar c121_inventarios ///
											c121_activos_nocorriente_venta c121_activos_biologi_nocorrie c121_gastos_pagados_anticipado ///
											c121_otros_activos_corrientes c121_propiedad_planta_equipo c121_activos_intangibles ///
											c121_propiedad_inversion c121_activos_explotacion_explo c121_cuentas_cobrarnocorrien ///
											c121_inversiones_no_corrientes c121_otros_acti_nocorrientes)

* Depreciation and provisions
egen double total_provisiones_c121 = rowtotal(c121_estima_cuentas_incobrabl c121_depreci_acumu_plant_equi c121_amorti_acumula_intangi ///
											  c121_depre_acumula_invers c121_expansion_inversiones c121_revaluacion_activos c121_obligaciones_financieras)

* Net assets using cells with the sum of total net assets (as it gets from the tax form itself)											  
gen double  total_net_assets_c121 = total_assets_c121 - total_provisiones_c121
gen double base_casillas = (total_net_assets_c121- 3000000)  
replace base_casillas = 0 if base_casillas<0
gen diff_casillas = base_casillas - baseimponactivoneto

* Net assets using cells with every item on assets (as it gets from the tax form itself)	
gen double base_activo_neto_past = (activocirculante + activofijo + activointangible + activodiferido + otrosactivos) - reservasdepreciacion - 3000000
replace base_activo_neto_past = 0 if base_activo_neto_past <=0
gen diff_activo_neto_past =base_activo_neto_past -  baseimponactivoneto


* Now, calculating taxable assets from balance sheet section
gen double base_act_preim = (efectivoeqalefectivo + inversionescorrientes + ctasdocxcobrar + ctasdocxcobrarp + inventarios + ///
							activosnocorrientesmv + activosbiologicos + gastospaganticipado + otrosactivoscorr + ///
							propiedadplantaeq + propiedadinversion + activosintangibles + activosbiologicosp + inversionesnocorr + ///
							otrosactnocorr - depreciaciondeterioro - 3000000) if formulario == 352
replace base_act_preim = 0 if base_act_preim < 0
gen diff_activo_neto_pre = base_act_preim - baseimponactivoneto


* Calculating taxable assets from financial statements section in paper forms
gen double total_activos_352 	= activoscorrientes +  activosnocorrientes - depreciaciondeterioro
gen double total_pasivo_352 	= pasivoscorrientes +  pasivosnocorr 
gen double total_pasivo_pat_352 = totalpatrimonio + total_pasivo_352

gen double base_imponible_352   = totalpasivomaspatrimonio  - 3000000
replace base_imponible_352 = 0 if base_imponible_352 < 0
gen diff_act_352 = base_imponible_352 - baseimponactivoneto


* Calculating taxable assets from additional column here
gen double base_sf = (totalactivosf - 3000000)
replace base_sf = 0 if base_sf<0
gen diff_sf = base_sf - baseimponactivoneto
summ diff_sf, d


* Identificator for the way every asset variable was constructed
gen indicador_activo = .
replace indicador_activo = 1 if abs(diff_casillas) < 10
replace indicador_activo = 2 if abs(diff_casillas) >= 10 & abs(diff_activo_neto_past) < 10
replace indicador_activo = 3 if abs(diff_casillas) >= 10 & abs(diff_activo_neto_past) >= 10 & abs(diff_activo_neto_pre) < 10
replace indicador_activo = 4 if abs(diff_casillas) >= 10 & abs(diff_activo_neto_past) >= 10 & abs(diff_activo_neto_pre) >= 10 & abs(diff_act_352) < 10
replace indicador_activo = 5 if abs(diff_casillas) >= 10 & abs(diff_activo_neto_past) >= 10 & abs(diff_activo_neto_pre) >= 10 & abs(diff_act_352) >= 10 & abs(diff_sf) < 10


* Taxable assets
gen		taxable_net_asset = .
replace taxable_net_asset = base_casillas 			if indicador_activo == 1
replace taxable_net_asset = base_activo_neto_past 	if indicador_activo == 2
replace taxable_net_asset = base_act_preim 			if indicador_activo == 3
replace taxable_net_asset = base_imponible_352 		if indicador_activo == 4
replace taxable_net_asset = base_sf 				if indicador_activo == 5
replace taxable_net_asset = baseimponactivoneto		if indicador_activo == .


* Gross assets. 
gen 	total_gross_assets = .
replace total_gross_assets = total_assets_c121	if indicador_activo == 1
replace total_gross_assets = (activocirculante + activofijo + activointangible + activodiferido + otrosactivos) if indicador_activo == 2
replace total_gross_assets = (efectivoeqalefectivo + inversionescorrientes + ctasdocxcobrar + ctasdocxcobrarp + inventarios + ///
							  activosnocorrientesmv + activosbiologicos + gastospaganticipado + otrosactivoscorr + ///
							  propiedadplantaeq + propiedadinversion + activosintangibles + activosbiologicosp + ///
							  inversionesnocorr + otrosactnocorr) 	if indicador_activo == 3
replace total_gross_assets = totalpasivomaspatrimonio 	if indicador_activo == 4
replace total_gross_assets = (totalactivosf + depreciaciondeterioro) if indicador_activo == 5 | indicador_activo == .


* Net assets. 
gen 	total_net_assets = .
replace total_net_assets = total_net_assets_c121 if indicador_activo == 1
replace total_net_assets = (activocirculante + activofijo + activointangible + activodiferido + otrosactivos - reservasdepreciacion) if indicador_activo == 2
replace total_net_assets = (efectivoeqalefectivo + inversionescorrientes + ctasdocxcobrar + ctasdocxcobrarp + inventarios + ///
							activosnocorrientesmv + activosbiologicos + gastospaganticipado + otrosactivoscorr + ///
							propiedadplantaeq + propiedadinversion + activosintangibles + activosbiologicosp + inversionesnocorr + ///
							otrosactnocorr - depreciaciondeterioro) if indicador_activo == 3
replace total_net_assets = totalpasivomaspatrimonio 	if indicador_activo == 4
replace total_net_assets = totalactivosf 				if indicador_activo == 5 | indicador_activo == .

* Converting gross and net assets in millions of Lempiras
gen total_net_assets_mil = total_net_assets/1000000
gen total_gross_assets_mil=total_gross_assets/1000000


*----------Investment and Capital Expenditure Variables----------*

**Gross PPE (measure 1)
gen ppe_gross=.
replace ppe_gross = c121_propiedad_planta_equipo if  indicador_activo == 1
replace ppe_gross = activofijo				     if  indicador_activo == 2 
replace ppe_gross = propiedadplantaeq            if  indicador_activo == 3 
replace ppe_gross = propiedadplantaeq 		   	 if  ppe_gross==.   // review here

**Gross PPE (measure 2 by JC)
gen ppe_gross1 = . 
replace ppe_gross1 = max(c121_propiedad_planta_equipo, activofijo, propiedadplantaeq)

/*
-->> Checking for the PPE with the less amount of zeros (JC)
g d = cond(c121_propiedad_planta_equipo > 0, 1, cond(activofijo >0, 2, cond(propiedadplantaeq >0, 3, .)))

tab d, miss
 d |      Freq.     Percent        Cum.
------------+-----------------------------------
          1 |     65,332       42.27       42.27
          2 |     35,642       23.06       65.34
          3 |     10,853        7.02       72.36
          . |     42,721       27.64      100.00
------------+-----------------------------------
      Total |    154,548      100.00
	  
tab year d, miss
           |                      d
      year |         1          2          3          . |     Total
-----------+--------------------------------------------+----------
      2011 |         0     10,941         31      3,291 |    14,263 
      2012 |         0     11,198         66      3,765 |    15,029 
      2013 |         0     11,795        120      4,046 |    15,961 
      2014 |     8,723      1,643      2,310      4,457 |    17,133 
      2015 |    11,837         64      2,517      5,710 |    20,128 
      2016 |    13,366          0      2,229      6,434 |    22,029 
      2017 |    14,984          1      1,933      7,056 |    23,974 
      2018 |    16,422          0      1,647      7,962 |    26,031 
-----------+--------------------------------------------+----------
     Total |    65,332     35,642     10,853     42,721 |   154,548 

tab formulario d, miss
           |                      d
formulario |         1          2          3          . |     Total
-----------+--------------------------------------------+----------
       350 |         0     19,624          0      3,983 |    23,607 
       352 |        23     11,299     10,803     19,169 |    41,294 
       357 |    65,309      4,719         50     19,569 |    89,647 
-----------+--------------------------------------------+----------
     Total |    65,332     35,642     10,853     42,721 |   154,548 
	 
As can be noticed, the PPE variable with the highest amount of values > 0 is "c121_propiedad_planta_equipo". 
Moreover, this fact is driven by time. Between 2011-2013, the variable "activofijo" is the one with the highest 
amount of values > 0. We should measure PPE as the max(c121_propiedad_planta_equipo, activofijo, propiedadplantaeq),
this strategy allows to substantially increase the number of observations with investment > 0.

gen ppe_gross1 = max(c121_propiedad_planta_equipo, activofijo, propiedadplantaeq)
g ppe1 = cond(ppe_gross > 0, 1, 0)
g ppe2 = cond(ppe_gross1 > 0, 1, 0)	
 
tabstat ppe1 ppe2, s(sum)

   Stats |      ppe1      ppe2
---------+--------------------
     Sum |     75146    111827
------------------------------
*/

* Comparing both distributions (Monica and JC gross PPE measures)
gen log_ppe1 = log(1 + ppe_gross)
gen log_ppe2 = log(1 + ppe_gross1)

**Depreciation PPE
**only available measure in the dataset is c121_depreci_acumu_plant_equi 
**from the balance sheet, there is more internal columns,but not in the dataset.
gen dep_property_plant_equipment=c121_depreci_acumu_plant_equi 


**PPE net: net book value of property , plant and equipment .
* Net PPE (Measure 1)
gen ppe_net=.
replace ppe_net = c121_propiedad_planta_equipo - c121_depreci_acumu_plant_equi  if  indicador_activo == 1
replace ppe_net = propiedadplantaeq - depreciaciondeterioro                     if  indicador_activo == 3 
replace ppe_net = activofijo - reservasdepreciacion				                if  indicador_activo == 2


* Net PPE (Measure 2 by JC)
gen depretiation1 = .
replace depretiation1 = max(c121_depreci_acumu_plant_equi, depreciaciondeterioro, reservasdepreciacion)

gen ppe_net1 = .
replace ppe_net1 = ppe_gross1 - depretiation1

* Comparing both distributions (Monica and JC net PPE measures)
gen log_ppe_net1 = log(1 + ppe_net)
gen log_ppe_net2 = log(1 + ppe_net1)

/*
g d = cond(c121_depreci_acumu_plant_equi > 0, 1, cond(depreciaciondeterioro >0, 2, cond(reservasdepreciacion >0, 3, .)))
tab d, miss
          d |      Freq.     Percent        Cum.
------------+-----------------------------------
          1 |     36,926       23.89       23.89
          2 |     12,624        8.17       32.06
          3 |     21,544       13.94       46.00
          . |     83,454       54.00      100.00
------------+-----------------------------------
      Total |    154,548      100.00
	  
tab year d, miss
           |                      d
      year |         1          2          3          . |     Total
-----------+--------------------------------------------+----------
      2011 |         0         15      6,578      7,670 |    14,263 
      2012 |         0         31      6,874      8,124 |    15,029 
      2013 |         0         47      7,242      8,672 |    15,961 
      2014 |     5,070      2,359        823      8,881 |    17,133 
      2015 |     6,596      2,691         26     10,815 |    20,128 
      2016 |     7,569      2,603          0     11,857 |    22,029 
      2017 |     8,434      2,510          1     13,029 |    23,974 
      2018 |     9,257      2,368          0     14,406 |    26,031 
-----------+--------------------------------------------+----------
     Total |    36,926     12,624     21,544     83,454 |   154,548 

tab formulario d, miss
           |                      d
formulario |         1          2          3          . |     Total
-----------+--------------------------------------------+----------
       350 |         0          0     13,954      9,653 |    23,607 
       352 |         9      5,635      4,251     31,399 |    41,294 
       357 |    36,917      6,989      3,339     42,402 |    89,647 
-----------+--------------------------------------------+----------
     Total |    36,926     12,624     21,544     83,454 |   154,548

*/


**PPE share
gen ppe_share_gross=ppe_gross/total_gross_assets
gen ppe_share_net=ppe_net/total_net_assets 


/*Construct Investment: need firms with two consecutive periods
	Net Investment: annual change in net book value of PPE2
	Gross Investment: annual change in gross book value of PPE2

*/

sort id year
bys id: gen yearprevious =year[_n-1]
bys id: gen yearless =year-1

gen consecutive=yearless==yearprevious //marking consecutive 
duplicates drop id year, force
xtset id year
sort id year

* Net investment
gen net_inv=(ppe_gross-L1.ppe_gross) 

* Net investment (JC)
gen net_inv1=(ppe_gross1-L1.ppe_gross1) 

* Gross investment
gen gross_inv=.
replace gross_inv=(ppe_gross-L1.ppe_gross) + dep_property_plant_equipment if  indicador_activo == 1
replace gross_inv=(ppe_gross-L1.ppe_gross) + depreciaciondeterioro        if  indicador_activo == 3
replace gross_inv=(ppe_gross-L1.ppe_gross) + reservasdepreciacion	      if  indicador_activo == 2

* Gross investment (JC)
gen gross_inv1 = .
replace gross_inv1 = (ppe_gross1 - L1.ppe_gross1) + depretiation1

* Investment rate
gen net_inv_rate=net_inv/L1.total_net_assets //investment rate.
gen L1total_net_assets_mil=L1.total_net_assets_mil // net assets previous period.
gen net_inv_rate1=net_inv1/L1.total_net_assets

**expenses in newly installed capital expenses. (non deductible in Honduras)
gen diff1=cyg_inversiones_g -ct_inversiones
gen investment_new=cyg_inversiones_g

  
 /*---CASHFLOW-------------------------------------------------------------------------------------------------------------------*/
sort id year
gen cash_stock = max(efectivoeqalefectivo, c121_efectivo_equivalent_efect) 

/* Current/non-current assets and liabilities */
rename activoscorrientes   current_assets 
rename activosnocorrientes noncurrent_assets
rename pasivoscorrientes   current_liab
rename pasivosnocorr 	   noncurrent_liab
rename gastospaganticipado advance_payments
rename activodiferido	   deferred_assets 
rename inventarios		   inventories


/*-------------------------------------------------------------------------------------------------------------------------------*/

drop tipo_ot tamaño_ot departamento nro_preimpreso fechapresentacion fechacierrerj fecha_constitucion fecha_inicio_actividad ///
	macro_desc macro_id descripcion
	
	foreach var of varlist ppe_gross ppe_net gross_inv net_inv ppe_gross1 ppe_net1 gross_inv1 net_inv1 cash_stock inventories ///
						   current_assets noncurrent_assets current_liab noncurrent_liab advance_payments deferred_assets financial {
		gen `var'_mil = `var' / 1000000 
	}
	

** Labeling variables				
lab var total_gross_revenue_mil		  "Revenue (Million L)"
lab var deduction_mil 				  "Deduction (Million L)"
lab var pre_tax_profits_mil 		  "Pre-tax profits (Million L)"
lab var after_tax_profits_mil		  "After-tax profits (Million L)"
lab var taxable_inc_rate 			  "Profit Rate"
lab var impuesto_mil 				  "Tax liability (Million L)"
lab var labor_costs_mil				  "Labor cost deductible (Million L)"
lab var labor_nd_mil				  "Labor cost non-deductible (Million L)"
lab var net_labor_mil				  "Labor cost net(Million L)"
lab var id 							  "Número de id de contribuyente"
lab var year 						  "Año de declaración fiscal"
lab var total_net_assets_mil		  "Net Assets (Million L)"
lab var ppe_gross_mil				  "Gross property_plant_equipment (Million L)"
lab var ppe_net_mil				  	  "Net property_plant_equipment (Million L)"
lab var ppe_gross1_mil				  "Gross property_plant_equipment (Million L), second alternatvie"
lab var ppe_net1_mil				  "Net property_plant_equipment (Million L), second alternatvie"
lab var cash_stock_mil 				  "Cash (Million L)"
lab var imp_segun_tarifa_renta 		  "Impuesto causado de RENTA"
lab var imp_segun_tarifa_activo_neto  "Impuesto causado de AN"
lab var imp_segun_tarifa_aport_solid  "Impuesto causado de AS"
lab var porcentaje_ing_brutos 		  "Impuesto mínimo del 1.5/0.75"
lab var current_assets_mil 			  "Current assets (Million L)"
lab var noncurrent_assets_mil 		  "Non-current assets (Million L)"
lab var current_liab_mil 	          "Current liabilities (Million L)"
lab var noncurrent_liab_mil           "Non-current liabilities (Million L)"
lab var deferred_assets_mil 		  "Deferred assets (Million L)"
lab var advance_payments_mil		  "Advance payments (Million L)"
lab var inventories_mil 			  "Inventories (Million L)"
lab var financial_mil 				  "Financial costs (Million L)"

cap drop diff2 yearprevious yearless
compress

keep id year total_gross_revenue_mil deduction_mil pre_tax_profits_mil after_tax_profits_mil impuesto_mil taxable_inc_rate labor_costs_mil labor_nd_mil net_labor_mil total_net_assets_mil total_gross_assets_mil ppe_gross_mil ppe_net_mil gross_inv_mil net_inv_mil L1total_net_assets_mil ppe_gross1_mil ppe_net1_mil gross_inv1_mil net_inv1_mil cash_stock_mil current_assets_mil noncurrent_assets_mil current_liab_mil noncurrent_liab_mil deferred_assets_mil advance_payments_mil inventories_mil financial_mil
order id year, first 
save "$databases/ISRPJ_workingdatabase.dta", replace

