/*=============================================================================
Name: 		 3b_Descriptives_CrossCountry_Refunds.do

Description: This do file produces Figure 1. The database was constructed 
			 manually using TADAT country reports.
			 https://www.tadat.org/performanceAssessmentReports

Input: 	     base_TADAT.xlsx
			 Bready.xlsx
			 
Output: 	 refunds_in_time.pdf
			 refunds_share.pdf
			 refunds_weeks.pdf
			 refunds_percent_firms_complicated.pdf
==============================================================================*/


/*******************************************************************************
			WORLD BANK OPEN DATATSET WITH GDP PER CAPITA
*******************************************************************************/

	preserve
		wbopendata, indicator(ny.gdp.pcap.pp.kd) clear long
		
		rename ny_gdp_pcap_pp_kd gdp_per_capita
		
		replace countryname = "Bahamas" if countryname == "Bahamas, The"
		replace countryname = "Congo, Dem. Rep." if countryname == "Congo, Dem Rep"
		replace countryname = "Congo, Rep." if countryname == "Congo, Rep"
		replace countryname = "Czechia" if countryname == "Czech Republic"
		replace countryname = "Egypt" if countryname == "Egypt, Arab Rep"
		replace countryname = "Gambia" if countryname == "Gambia, The"
		replace countryname = "Micronesia" if countryname == "Micronesia, Fed Sts"
		replace countryname = "Russia" if countryname == "Russian Federation"
		replace countryname = "Slovakia" if countryname == "Slovak Republic"
		replace countryname = "St. Vincent and the Grenadines" if countryname == "St Vincent and the Grenadines"
		replace countryname = "St. Lucia" if countryname == "St Lucia"
		replace countryname = "St. Kitts and Nevis" if countryname == "St Kitts and Nevis"
		replace countryname = "Turkiye" if countryname == "Turkey"
		replace countryname = "Venezuela" if countryname == "Venezuela, RB"
		replace countryname = "Yemen" if countryname == "Yemen, Rep"
		
		* All years to match with TADAT
		tempfile gdp_allyears
		save `gdp_allyears'
		
		* Only 2023 to match with B-Ready
		keep if year == 2023
		tempfile gdp_2023
		save `gdp_2023'
	restore


	
/*******************************************************************************
					USING TADAT RECORDS
*******************************************************************************/

* Import data base
	import excel using "$rawdata/base_TADAT.xlsx", firstrow clear
	drop H I


* Merge with GDP Per capita income from the World Bank open dataset
	replace year = cond(countrycode == "TON", 2020, year)		// GDP is not available for Tonga in 2021, so I replace it for 2020 GDP
	merge 1:1 countrycode year using `gdp_allyears', keepusing(gdp_per_capita)
	keep if _merge == 3
	drop _merge


* Measures on VAT refunds
	gen refunds_out_time = (1 - refunds_in_time) * 100
	gen share_refunds = vat_refunds / (vat_domestic_revenue + vat_import_revenue) * 100
	gen log_gdp = log(gdp_per_capita)

	replace refunds_in_time = refunds_in_time * 100

	label var log_gdp 		   "Log(GDP Per Capita, PPP)"
	label var refunds_out_time "VAT refunds not paid/declined within 30 days"
	label var refunds_in_time  "VAT refunds paid/declined within 30 days"
	label var share_refunds    "VAT refunds as % of VAT total revenue"


* Identifying Honduras for highlighting in the scatterplot
	gen hnd 	  = countrycode if strpos(countrycode, "HND")   									
	gen hnd_gdp   = log_gdp 		 if countrycode == "HND"
	gen hnd_out   = refunds_out_time if countrycode == "HND"
	gen hnd_share = share_refunds 	 if countrycode == "HND"
	gen hnd_in    = refunds_in_time  if countrycode == "HND"


* ========================== FIGURE 1 ========================== 
	* The World Bank updates GDP per capita statistics, so this graph could change
	reg refunds_in_time log_gdp, vce(robust)
	loc b1:  di %3.2f _b[log_gdp]
	loc se1: di %3.2f _se[log_gdp]
	loc n1:  di %2.0f e(N)

	reg share_refunds log_gdp, vce(robust)
	loc b2:  di %3.2f _b[log_gdp]
	loc se2: di %3.2f _se[log_gdp]
	loc n2:  di %2.0f e(N)

	twoway (scatter refunds_in_time log_gdp, mlcolor(blue) mfcolor(blue%50) msize(medlarge)) ///
		   (lfit refunds_in_time log_gdp, lcolor(navy)), ytitle("VAT refunds paid/declined within 30 days") ///
		   note("Slope(SE) = `b1'(`se1');  N=`n1'", size(medsmall)) yscale(titlegap(3)) xscale(titlegap(3)) ///
		   legend(off) ylabel(0 "0%" 20 "20%" 40 "40%" 60 "60%" 80 "80%" 100 "100%") $graphopt xlabel(7(1)11)
		   graph export "$figures/refunds_in_time_without.pdf", replace

	twoway (scatter refunds_in_time log_gdp if missing(hnd), mlcolor(blue) mfcolor(blue%50) msize(medlarge)) ///
		   (scatter hnd_in hnd_gdp, msymbol(triangle) mcolor(red) mlabel(hnd) mlabcolor(red) msize(medlarge)) ///
		   (lfit refunds_in_time log_gdp, lcolor(navy)), ytitle("VAT refunds paid/declined within 30 days") ///
		   note("Slope(SE) = `b1'(`se1');  N=`n1'", size(medsmall)) yscale(titlegap(3)) xscale(titlegap(3)) ///
		   legend(off) ylabel(0 "0%" 20 "20%" 40 "40%" 60 "60%" 80 "80%" 100 "100%") $graphopt xlabel(7(1)11)
		   graph export "$figures/refunds_in_time.pdf", replace
		   
	twoway (scatter share_refunds log_gdp, mlcolor(blue) mfcolor(blue%50) msize(medlarge)) ///
		   (lfit share_refunds log_gdp, lcolor(navy)), ytitle("VAT refunds as % of VAT total revenue") ///
		   note("Slope(SE) = `b2'(`se2');  N=`n2'", size(medsmall)) yscale(titlegap(3)) xscale(titlegap(3)) ///
		   legend(off) ylabel(0 "0%" 20 "20%" 40 "40%" 60 "60%" 80 "80%" 100 "100%") $graphopt xlabel(7(1)11)
		   graph export "$figures/refunds_share_without.pdf", replace
		  
	twoway (scatter share_refunds log_gdp if missing(hnd), mlcolor(blue) mfcolor(blue%50) msize(medlarge)) ///
		   (scatter hnd_share hnd_gdp, msymbol(triangle) mcolor(red) mlabel(hnd) mlabcolor(red) msize(medlarge)) ///
		   (lfit share_refunds log_gdp, lcolor(navy)), ytitle("VAT refunds as % of VAT total revenue") ///
		   note("Slope(SE) = `b2'(`se2');  N=`n2'", size(medsmall)) yscale(titlegap(3)) xscale(titlegap(3)) ///
		   legend(off) ylabel(0 "0%" 20 "20%" 40 "40%" 60 "60%" 80 "80%" 100 "100%") $graphopt xlabel(7(1)11)
		   graph export "$figures/refunds_share.pdf", replace
	   
	   

	
/*******************************************************************************
							USING B-READY RECORDS
*******************************************************************************/

* Import data base and prepare outomes of interest
	import excel using "$rawdata/Bready.xlsx", firstrow clear	
	keep Economy BREADYWeekstoreceiveVATr BREADYPercentoffirmsrepor 
	
	drop if Economy == "All Countries" | Economy == "East Asia & Pacific" | Economy == "Europe & Central Asia" | ///
		    Economy == "Latin America & Caribbean" | Economy == "Middle East & North Africa" | ///
			Economy == "South Asia" | Economy == "Sub-Saharan Africa"	
	
* Merge with GDP Per capita income from the World Bank open dataset	
	rename Economy countryname 
	replace countryname = "Vietnam" if countryname == "Viet Nam"
	
	merge 1:1 countryname using `gdp_2023', keepusing(gdp_per_capita)
	keep if _merge == 3
	drop _merge
	
* Adjusting variables
	gen log_gdp = log(gdp_per_capita)
	
	replace BREADYWeekstoreceiveVATr  = "" if BREADYWeekstoreceiveVATr == "n.a."
	replace BREADYPercentoffirmsrepor = "" if BREADYPercentoffirmsrepor == "n.a."
	
	destring BREADYWeekstoreceiveVATr, replace
	destring BREADYPercentoffirmsrepor, replace
	
* Label variables	
	label var log_gdp 		   		    "Log(GDP Per Capita, PPP)"
	label var BREADYWeekstoreceiveVATr  "Weeks to receive VAT refund"
	label var BREADYPercentoffirmsrepor "% firms not claim VAT refund bc. complicated"

* Identifying Honduras for highlighting in the scatterplot
	gen hnd 	  = countryname if strpos(countryname, "Honduras")   									
	gen hnd_gdp   = log_gdp 		 		  if countryname == "Honduras"
	gen hnd_weeks = BREADYWeekstoreceiveVATr  if countryname == "Honduras"
	gen hnd_share = BREADYPercentoffirmsrepor if countryname == "Honduras"
	
* Figures
	reg BREADYWeekstoreceiveVATr log_gdp, vce(robust)
	loc b3:  di %3.2f _b[log_gdp]
	loc se3: di %3.2f _se[log_gdp]
	loc n3:  di %2.0f e(N)

	reg BREADYPercentoffirmsrepor log_gdp, vce(robust)
	loc b4:  di %3.2f _b[log_gdp]
	loc se4: di %3.2f _se[log_gdp]
	loc n4:  di %2.0f e(N)

	twoway (scatter BREADYWeekstoreceiveVATr log_gdp if missing(hnd), mlcolor(blue) mfcolor(blue%50) msize(medlarge)) ///
		   (scatter hnd_weeks hnd_gdp, msymbol(triangle) mcolor(red) mlabel(hnd) mlabcolor(red) msize(medlarge)) ///
		   (lfit BREADYWeekstoreceiveVATr log_gdp, lcolor(navy)), ytitle("Weeks to receive VAT refund") ///
		   note("Slope(SE)= `b3'(`se3');  N=`n3'", size(medsmall)) yscale(titlegap(3)) xscale(titlegap(3)) ///
		   legend(off) $graphopt ylabel(0(5)40) xlabel(7(1)12)
		   graph export "$figures/refunds_weeks.pdf", replace
		  
	twoway (scatter BREADYPercentoffirmsrepor log_gdp if missing(hnd), mlcolor(blue) mfcolor(blue%50) msize(medlarge)) ///
		   (scatter hnd_share hnd_gdp, msymbol(triangle) mcolor(red) mlabel(hnd) mlabcolor(red) msize(medlarge)) ///
		   (lfit BREADYPercentoffirmsrepor log_gdp, lcolor(navy)), ytitle("% firms not claim VAT refund because takes too long") ///
		   note("Slope(SE)= `b4'(`se4');  N=`n4'", size(medsmall)) yscale(titlegap(3)) xscale(titlegap(3)) ///
		   legend(off) ylabel(0 "0%" 20 "20%" 40 "40%" 60 "60%" 80 "80%" 100 "100%") $graphopt xlabel(7(1)11)
		   graph export "$figures/refunds_percent_firms_complicated.pdf", replace	
	