/*=============================================================================
Name: 		 4c_PrepareTime_Invariant.do

Description: This do-file creates true income for firms in sample, and additional 
		     time-invariant categories such as: pre-reform quartile of income,
		     liquidity constraints, and capital intensity 

Input: 	     ISV_panel_vars.dta
			 firmlevel_TreatStatus.dta
			 Firm_traits.dta
			 ISRPN_workingdatabase.dta
			 ISRPJ_workingdatabase.dta
			 
Output: 	 Annual_sales.dta
			 heterogeneity_traits.dta
			 liquidity_histogram_pooled.pdf
			 liquidity_histogram_split.pdf
			 capitalint_histogram_pooled.pdf
			 capitalint_histogram_split.pdf
==============================================================================*/


*===============================================================================
*** 1. Building true value of income and time invariant income quintiles
*===============================================================================

* Loading VAT records
	use if year >= 2014 using "$databases/ISV_panel_vars.dta", clear

* Merge with treatment/control status
	merge m:1 id using "$databases/firmlevel_TreatStatus.dta"
	drop if _merge == 2
	drop _merge
	
* Adding firm characteristics
	merge m:1 id using "$databases/Firm_traits.dta", keep(1 3) keepusing(activity_sector tipo dept risk_score)
	drop _merge
	
	
* Building traits on legal type and industry
	gen category = cond(tipo == 2, 0, 1)
	lab def category 0 "Personal business" 1 "Corporate"
	lab val category category	
	
	gen retail 		  = (activity_sector == 6)
	gen manufacturing = (activity_sector == 2)
	gen wholesale     = (activity_sector == 5)
	gen services      = inrange(activity_sector,7,11) 
	
	lab var retail        	 "Retail"
	lab var manufacturing 	 "Manufacturing"
	lab var wholesale        "Wholesale"	
	lab var services 		 "Services"

* True value of income 
	gcollapse (first) balanced_* treat0_* treat1_* treat2_* treat3_* treat4_* tipo activity_sector category ///
			   retail manufacturing wholesale services dept risk_score (mean) share_withheld				///
			   (sum) total_revenue net_liability_th gross_liability_th credits_th exports_th, by(id year)
	gen pre = (year < 2017)
	
	* Define exporter firms 
	gen exporter = cond(exports_th > 0 & exports_th != ., 1, 0)
	lab def exporter 0 "Non-Exporter" 1 "Exporter"
	lab val exporter exporter
	
	* Merge with income tax data
	merge 1:1 id year using "$databases/ISRPN_workingdatabase.dta", ///
	keepusing(total_gross_revenue_mil ppe_gross_mil current_assets_mil cash_stock_mil total_net_assets_mil total_gross_assets_mil) gen(mergePN)
	drop if mergePN == 2
	
	merge 1:1 id year using  "$databases/ISRPJ_workingdatabase.dta",  ///
	keepusing(total_gross_revenue_mil ppe_gross1_mil current_assets_mil cash_stock_mil total_net_assets_mil total_gross_assets_mil) gen(mergePJ) replace update
	drop if mergePJ == 2
	drop mergePN  mergePJ

	gen total_vat_revenue_mil = total_revenue / 1000000
	g dif = total_gross_revenue_mil - total_vat_revenue_mil

	qui sum id if missing(dif)
	loc n1 = r(N)
	qui sum id
	loc n2 = r(N)
	loc missing_n: di %3.1f `n1' / `n2'
	dis "Missing differences is `missing_n'% of observations"
	
	* Our prefered measure of total revenue is the max between VAT and income tax 
	gen final_revenue_mil = max(total_gross_revenue_mil, total_vat_revenue_mil)
	label var final_revenue_mil "Anual sales"
	
	gen max_income_tax = (total_gross_revenue_mil > total_vat_revenue_mil)
	label var max_income_tax "=1 if income tax revenue > vat annual revenue"
	
	
* Building quartiles of income for the pre-reform period and different T&C groups
	sort id year
	bys id: egen pre_reform_sales_avg = mean(final_revenue_mil) if pre == 1

	local balance quarter_1418 quarter_1419 quarter_1518 quarter_1519 month_1418 month_1419 month_1518 month_1519
	
	foreach k of local balance {
		
		forvalues j = 0/4 {
				
			preserve
				keep if year == 2016 & !missing(treat`j'_balanced_`k')					
			
				xtile quantile`j'_`k' = pre_reform_sales_avg, nq(4)
			
					forvalues i = 1/4 {
						qui sum pre_reform_sales_avg if quantile`j'_`k' == `i'
						loc min_`i': di %4.2f r(min)
						loc max_`i': di %4.2f r(max)
					}
			
				lab def quant`j'_`k' 1 "`min_1'-`max_1' (1M L)" 2 "`min_2'-`max_2' (1M L)" 3 "`min_3'-`max_3' (1M L)" 4 "> `min_4' (1M L)"
				lab val quantile`j'_`k' quant`j'_`k'
				lab var quantile`j'_`k' "Size based on pre-reform annual sales, `k'"

				keep id quantile`j'_`k'
				tempfile quant`j'_`k'
				save     "`quant`j'_`k''"		
			restore

			merge m:1 id using "`quant`j'_`k''", keepusing(quantile`j'_`k')
			drop _merge
		}
	}
	
	
* Saving dataset with the true annual income and with quartiles of income in 2016	
preserve
	keep id year final_revenue_mil max_income_tax pre_reform_sales_avg quantile*
	compress	 
	save "$databases/Annual_sales.dta", replace	
restore	
	
	
*===============================================================================
*** 3. Identifying firms with high & low net VAT (overwithheld)
*===============================================================================

preserve
	keep if year == 2016
	
	gen net_share = net_liability_th/gross_liability_th
	gen net_below = (net_share <= 0.5)
	
	qui sum net_share, d
	gen net_below_median = (net_share <= `r(p50)')
	
	lab def net_below 0 "Above 0.5 net VAT" 1 "Below 0.5 net VAT"
	lab val net_below net_below
	
	lab def net_below_median 0 "Above median net VAT" 1 "Below median net VAT"
	lab val net_below_median net_below_median
	
	tempfile net_vat
	save "`net_vat'"
restore
	
merge m:1 id using "`net_vat'", keepusing(net_below net_below_median)
drop _merge



*===============================================================================
*** 3. Identifying cash-constrained and capital intensive firms 
*===============================================================================	
	
	* This traits are only produced for treatment and control firms in the baseline intensive margin (p25 & p75, respectively) 
	* because heterogeneity analysis is being carried out for the baseline T&C group only.

foreach k of local balance {
		
	preserve
		keep if !missing(treat0_balanced_`k')
			
	* Cash constrained firms: cash to net-assets ratio below the median in the pre-reform period
		gen cash_to_assets = cash_stock_mil / total_gross_assets_mil
		replace cash_to_assets = cond(cash_to_assets > 1 & !missing(cash_to_assets), 1, cash_to_assets)
		replace cash_to_assets = cond(cash_to_assets < -0 & !missing(cash_to_assets), 0.01, cash_to_assets)
		
		sort id year
		bys id: egen pre_reform_cash1 = mean(cash_to_assets) if pre == 1
		gegen pre_reform_cash2 = max(pre_reform_cash1), by(id)
		gen liquidity_`k' = pre_reform_cash2
		label var liquidity_`k' "Pre-reform liquidity: `k'"
		
		qui sum pre_reform_cash2, d
		gen low_cash_`k' = cond(pre_reform_cash2 < `r(p50)' & !missing(pre_reform_cash2), 1, ///
						   cond(!missing(pre_reform_cash2), 0, .))
		
		lab def cash_`k' 0 "High Cash" 1 "Low Cash"
		lab val low_cash_`k' cash_`k'
					   
	* Capital intensive firms: physical to net-assets ratio below the median in the pre-reform period
		
		* Harmonize the book value of physical assets
		gen ppe_gross2 = cond(tipo == 1 & !missing(ppe_gross1_mil) & ppe_gross1_mil > 0, ppe_gross1_mil, ///
						 cond(tipo == 2 & !missing(ppe_gross_mil) & ppe_gross_mil > 0, ppe_gross_mil, 0))
						 
		gen capital_to_sales = ppe_gross2 / final_revenue_mil
		replace capital_to_sales = cond(capital_to_sales > 1 & !missing(capital_to_sales), 1, capital_to_sales)
		replace capital_to_sales = cond(capital_to_sales < -0 & !missing(capital_to_sales), 0.01, capital_to_sales)

		sort id year
		bys id: egen pre_reform_capital1 = mean(capital_to_sales) if pre == 1
		gegen pre_reform_capital2 = max(pre_reform_capital1), by(id)
		gen capitalint_`k' = pre_reform_capital2
		label var capitalint_`k' "Pre-reform capital intensity: `k'"
		
		qui sum pre_reform_capital2, d
		gen capital_intensive_`k' = cond(pre_reform_capital2 >= `r(p50)' & !missing(pre_reform_capital2), 1, ///
									cond(!missing(pre_reform_capital2), 0, .))
		
		lab def capital_`k' 0 "Non-Capital Intensive" 1 "Capital Intensive"
		lab val capital_intensive_`k' capital_`k'
		
		keep if year == 2016
		keep id low_cash_`k' capital_intensive_`k' liquidity_`k' capitalint_`k'
		
		tempfile traits_`k'
		save "`traits_`k''"
	restore
	
	merge m:1 id using "`traits_`k''", keepusing(low_cash_`k' liquidity_`k' capital_intensive_`k' capitalint_`k')
	drop _merge
	
}

* Save data with time-invariant characteristics
	preserve
		keep if year == 2016
		keep id activity_sector exporter category retail manufacturing wholesale low_cash_* ///
			 capital_intensive_* retail manufacturing wholesale services tipo dept risk_score ///
			 net_below net_below_median
		compress
		save "$databases/heterogeneity_traits.dta", replace
	restore



*===============================================================================
* 4. Conditional distribution of capital intensity and liquidity
*===============================================================================	
		
preserve
	keep if year == 2016 & !missing(treat0_balanced_${vat_freq}_${vat_since}${vat_to})
	
	* Liquidity, baseline sample
	qui sum liquidity_${vat_freq}_${vat_since}${vat_to} if !missing(treat0_balanced_${vat_freq}_${vat_since}${vat_to}), d
	loc x = `r(p50)' + 0.1
	
	hist liquidity_${vat_freq}_${vat_since}${vat_to}, lcolor(dknavy%70) fcolor(dknavy%70) ///
	     xline(`r(p50)', lp(dash) lc(dknavy) lw(thin)) $graphopt ///
	     xtitle("Cash to total assets") ytitle("Density") xscale(titlegap(3)) yscale(titlegap(3)) ///
		 text(.25 `x' "Median ratio", size(small)) frac
		 graph export "$figures/liquidity_histogram_pooled.pdf", replace
		 
	qui sum liquidity_${vat_freq}_${vat_since}${vat_to} if !missing(treat0_balanced_${vat_freq}_${vat_since}${vat_to}), d
	loc x = `r(p50)' + 0.1	 
	
	 twoway (hist liquidity_${vat_freq}_${vat_since}${vat_to} if treat0_balanced_${vat_freq}_${vat_since}${vat_to} == 0, lcolor(dknavy%70) fcolor(dknavy%70) frac) ///
            (hist liquidity_${vat_freq}_${vat_since}${vat_to} if treat0_balanced_${vat_freq}_${vat_since}${vat_to} == 1, lcolor(dknavy) fcolor(none) frac), ///
	        legend(row(2) order(1 "Low DCC usage" 2 "High DCC usage") pos(2) ring(0)) xline(`r(p50)', lp(dash) lc(dknavy) lw(thin)) ///
	        xtitle("Cash to total assets") ytitle("Density") xscale(titlegap(3)) yscale(titlegap(3)) ///
			text(.25 `x' "Median ratio", size(small)) $graphopt
            graph export "$figures/liquidity_histogram_split.pdf", replace
			
	* Capital intensity, baseline sample		
    qui sum capitalint_${vat_freq}_${vat_since}${vat_to} if !missing(treat0_balanced_${vat_freq}_${vat_since}${vat_to}), d
	loc x1 = `r(p50)' + 0.1
	
	hist capitalint_${vat_freq}_${vat_since}${vat_to}, lcolor(dknavy%70) fcolor(dknavy%70) ///
	     xline(`r(p50)', lp(dash) lc(dknavy) lw(thin)) $graphopt ///
	     xtitle("Physical assets to sales") ytitle("Density") xscale(titlegap(3)) yscale(titlegap(3)) ///
		 text(.25 `x1' "Median ratio", size(small)) frac
		 graph export "$figures/capitalint_histogram_pooled.pdf", replace
		 
	qui sum capitalint_${vat_freq}_${vat_since}${vat_to} if !missing(treat0_balanced_${vat_freq}_${vat_since}${vat_to}), d
	loc x1 = `r(p50)' + 0.1	 
	
	 twoway (hist capitalint_${vat_freq}_${vat_since}${vat_to} if treat0_balanced_${vat_freq}_${vat_since}${vat_to} == 0, lcolor(dknavy%70) fcolor(dknavy%70) frac) ///
            (hist capitalint_${vat_freq}_${vat_since}${vat_to} if treat0_balanced_${vat_freq}_${vat_since}${vat_to} == 1, lcolor(dknavy) fcolor(none) frac), ///
	        legend(row(2) order(1 "Low DCC usage" 2 "High DCC usage") pos(2) ring(0)) xline(`r(p50)', lp(dash) lc(dknavy) lw(thin)) ///
	        xtitle("Physical assets to sales") ytitle("Density") xscale(titlegap(3)) yscale(titlegap(3)) ///
			text(.25 `x1' "Median ratio", size(small)) $graphopt
            graph export "$figures/capitalint_histogram_split.pdf", replace	
restore
	
	
	
