/*==============================================================================
Name: 		 4e_PreparePanelReform_ISR.do

Description: This do-file creates dataset from income tax records ready for analysis.

Input: 	     ISV_panel_vars.dta
			 ISRPN_workingdatabase.dta
			 ISRPN_workingdatabase.dta
			 firmlevel_TreatStatus.dta
			 Annual_sales.dta
			 heterogeneity_traits.dta
			 
Output: 	 ISR_reform_panel.dta
==============================================================================*/


/*******************************************************************************	
 1. Import income tax records and prepare dataset for manipulation
*******************************************************************************/

* We take taxpayers from VAT records as the baseline
	use id year month if year >= 2014 using "$databases/ISV_panel_vars.dta", clear
	duplicates drop id year, force
	

* Import personal income tax (PIT) and corporate income tax (CIT) records 
	merge 1:1 id year using "$databases/ISRPN_workingdatabase.dta", keep(1 3) 
	merge 1:1 id year using  "$databases/ISRPJ_workingdatabase.dta", keep(1 3 4 5) gen(mergePJ) update replace
	drop _merge mergePJ month
	
	
* Merge with treatment/control and set to missing the years that are not covered by sample
	merge m:1 id using "$databases/firmlevel_TreatStatus.dta", keep(1 3)
	drop _merge
	
	forvalues i = 0/4 {
		replace treat`i'_balanced_${vat_freq}_1418 = . if year == 2019
		replace treat`i'_balanced_${vat_freq}_1518 = . if year == 2014 | year == 2019 
		replace treat`i'_balanced_${vat_freq}_1519 = . if year == 2014
	}
	
	
* Merge with true value of income
	merge 1:1 id year using "$databases/Annual_sales.dta", keepusing(final_revenue_mil) keep(1 3)
	drop _merge
	
	
* Merge with legal category (corporate or non-incorporated business)
	merge m:1 id using "$databases/heterogeneity_traits.dta", keepusing(category tipo) keep(1 3)
	drop _merge
	

****IMPORTANT EDIT: IF FIRM IS NEVER IN ANY BALANCED PANEL, JUST DROP IT BC IT WON'T BE USED IN ANY ANALYSIS
 egen any_balance = rowmax(balanced_quarter_1418 balanced_quarter_1419 balanced_quarter_1518 balanced_quarter_1519)
 keep if any_balance == 1
 
	
/*******************************************************************************	
 2. Build additional relevant outcomes for analysis
*******************************************************************************/
	
	
* Rename variables conveniently (so names are not that large after adding winsor suffix)	
	rename (pre_tax_profits_mil after_tax_profits_mil current_assets_mil noncurrent_assets_mil current_liab_mil ///
			noncurrent_liab_mil cash_stock_mil labor_costs_mil advance_payments_mil inventories_mil deduction_mil financial_mil) ///
		   (pre_tax_profits after_tax_profits current_assets noncurrent_assets current_liab noncurrent_liab cash_stock labor_costs advance_pay inventories deduction financial)
		   
		   
* Harmonizing investment outcomes
	gen ppe_gross2 = cond(tipo == 1 & !missing(ppe_gross1_mil) & ppe_gross1_mil > 0, ppe_gross1_mil, ///
					 cond(tipo == 2 & !missing(ppe_gross_mil) & ppe_gross_mil > 0, ppe_gross_mil, 0))	
					  
	gen ppe_net2 = cond(tipo == 1 & !missing(ppe_net1_mil) & ppe_net1_mil > 0, ppe_net1_mil, ///
				   cond(tipo == 2 & !missing(ppe_net_mil) & ppe_net_mil > 0, ppe_net_mil, 0))	
				   
	gen inv_gross2 = cond(tipo == 1 & !missing(gross_inv1_mil) & gross_inv1_mil > 0, gross_inv1_mil, ///
					 cond(tipo == 2 & !missing(gross_inv_mil) & gross_inv_mil > 0, gross_inv_mil, 0))	
					 
	gen inv_net2 = cond(tipo == 1 & !missing(net_inv1_mil) & net_inv1_mil > 0, net_inv1_mil, ///
				   cond(tipo == 2 & !missing(net_inv_mil) & net_inv_mil > 0, net_inv_mil, 0))
				   
	tsset id year
	gen gross_inv_rate1 = inv_gross2 / total_net_assets_mil
	gen net_inv_rate1   = inv_net2 / total_net_assets_mil
	
	winsor2 gross_inv_rate1, cuts(1 95) 
	winsor2 net_inv_rate1, cuts(1 95)
	
	rename gross_inv_rate1_w gross_inv_rate
	rename net_inv_rate1_w	 net_inv_rate
	
	gen lag_gross_inv_rate = L1.gross_inv_rate
	gen lag_net_inv_rate   = L1.net_inv_rate
				   
				   
* Extensive margins
	gen prob_inv_gross  = cond(inv_gross2 > 0, 1, 0)
	gen prob_inv_net    = cond(inv_net2 > 0, 1, 0)
	gen prob_advancepay = cond(advance_pay > 0 & !mi(advance_pay), 1, 0)
	gen prob_inventory  = cond(inventories > 0 & !mi(inventories), 1, 0)

	
* Adjusting final revenue in 2016
	gen final_revenue_16_a = final_revenue_mil if year == 2016
	gegen final_revenue_16 = max(final_revenue_16_a), by(id)
	gen post = (year >= 2017)

	

/*******************************************************************************	
 3. Normalization with respect to pre-reform sales in 2016 (Kennedy et. al 2023)
*******************************************************************************/

	local balance 1418 1419 1518 1519
	
* First, the dummy for the probability of investment is replicated according to each of T&C groups, so it can be included in loops easily.
	forvalues i = 0/4 {
		foreach bal of local balance {
			gen byte prob_inv_gross_n_`i'_`bal'_w999 = prob_inv_gross if !missing(treat`i'_balanced_${vat_freq}_`bal')
			gen byte prob_inv_gross_n_`i'_`bal'_w99  = prob_inv_gross if !missing(treat`i'_balanced_${vat_freq}_`bal')
			gen byte prob_inv_gross_n_`i'_`bal'_w95  = prob_inv_gross if !missing(treat`i'_balanced_${vat_freq}_`bal')
			
			gen byte prob_inv_net_n_`i'_`bal'_w999 = prob_inv_net if !missing(treat`i'_balanced_${vat_freq}_`bal')
			gen byte prob_inv_net_n_`i'_`bal'_w99  = prob_inv_net if !missing(treat`i'_balanced_${vat_freq}_`bal')
			gen byte prob_inv_net_n_`i'_`bal'_w95  = prob_inv_net if !missing(treat`i'_balanced_${vat_freq}_`bal')
			
			gen byte prob_advancepay_n_`i'_`bal'_w999 = prob_advancepay if !missing(treat`i'_balanced_${vat_freq}_`bal')
			gen byte prob_advancepay_n_`i'_`bal'_w99  = prob_advancepay if !missing(treat`i'_balanced_${vat_freq}_`bal')
			gen byte prob_advancepay_n_`i'_`bal'_w95  = prob_advancepay if !missing(treat`i'_balanced_${vat_freq}_`bal')
			
			gen byte prob_inventory_n_`i'_`bal'_w999 = prob_inventory if !missing(treat`i'_balanced_${vat_freq}_`bal')
			gen byte prob_inventory_n_`i'_`bal'_w99  = prob_inventory if !missing(treat`i'_balanced_${vat_freq}_`bal')
			gen byte prob_inventory_n_`i'_`bal'_w95  = prob_inventory if !missing(treat`i'_balanced_${vat_freq}_`bal')
		}
	}
	

* Secondly, continuous outcomes are normalized with sales.
* Winsorizing is made at the sample level, so it changes according to balancedness and T&C definitions.
* Be aware that profits are also winsorized at the 1st fraction of observations due to outliers.

	foreach var of varlist ppe_gross2 ppe_net2 inv_gross2 inv_net2 cash_stock labor_costs pre_tax_profits deduction financial ///
						   after_tax_profits current_assets noncurrent_assets current_liab noncurrent_liab advance_pay inventories {
					
		* Normalization using pre-reform sales
		gen `var'_n = `var' / final_revenue_16	
		
		* Winsorizing
		forvalues i = 0/4 {
				di in red "Winsorizing for variable: `var' and Treatment `i'"
			foreach bal of local balance {
			
				if `var' == pre_tax_profits | `var' == after_tax_profits {																					
					winsor2 `var'_n if !missing(treat`i'_balanced_${vat_freq}_`bal'), cuts(1 99.9) suffix(_`i'_`bal'_w999)
					winsor2 `var'_n if !missing(treat`i'_balanced_${vat_freq}_`bal'), cuts(1 99)   suffix(_`i'_`bal'_w99)	
					winsor2 `var'_n if !missing(treat`i'_balanced_${vat_freq}_`bal'), cuts(1 95)   suffix(_`i'_`bal'_w95)									
				}
				else {									
					winsor2 `var'_n if !missing(treat`i'_balanced_${vat_freq}_`bal'), cuts(0 99.9) suffix(_`i'_`bal'_w999)
					winsor2 `var'_n if !missing(treat`i'_balanced_${vat_freq}_`bal'), cuts(0 99)   suffix(_`i'_`bal'_w99)	
					winsor2 `var'_n if !missing(treat`i'_balanced_${vat_freq}_`bal'), cuts(0 95)   suffix(_`i'_`bal'_w95)		
				}	
			}
		}	
						   	
	}
	
	
	
/*******************************************************************************	
 4. Adding labels, and saving final dataset
*******************************************************************************/

* Adding labels to prefix of the variables only
	lab var ppe_gross2 		  "Gross PPE"
	lab var ppe_net2 		  "Net PPE"
	lab var inv_gross2 		  "Gross Investment"
	lab var inv_net2 		  "Net Investment"
	lab var cash_stock	      "Cash"
	lab var labor_costs		  "Wage Bill"
	lab var pre_tax_profits   "Pre-Tax Profits"
	lab var after_tax_profits "After-Tax Profits" 
	lab var current_assets 	  "Current Assets"
	lab var noncurrent_assets "Non-Current Assets"
	lab var current_liab      "Current Liabilities"
	lab var noncurrent_liab   "Non-Current Liabilities"
	lab var prob_inv_gross    "Pr(Gross Investment = 1)"
	lab var prob_inv_net	  "Pr(Net Investment = 1)"
	lab var advance_pay		  "Payments in advance"
	lab var prob_advancepay   "Pr(Advanced Payments = 1)"
	lab var gross_inv_rate    "Gross investment rate"
	lab var net_inv_rate	  "Net investment rate"
	lab var prob_inventory    "Pr(Inventories = 1)"
	lab var inventories		  "Inventories"
	lab var deduction  		  "Deductions"
	lab var financial 		  "Financial Costs"
	
* Let's keep variables of interest only
	keep id year post ppe_gross2* ppe_net2* inv_gross2* inv_net2* cash_stock* labor_costs* pre_tax_profits* after_tax_profits* prob_advancepay* ///
					 current_assets* noncurrent_assets* current_liab* noncurrent_liab* prob_inv_gross* prob_inv_net* advance_pay* gross_inv_rate ///
					 net_inv_rate prob_inventory* inventories* deduction* financial*
	order id year post, first
	
	
* Saving working dataset, ready for estimations
	compress
	save "$databases/ISR_reform_panel.dta", replace	
	
	
	
