/*==============================================================================
Name: 		 4e_PreparePanelReform_ISV.do

Description: This do-file creates dataset from VAT records ready for analysis.

Input: 	     ISV_panel_vars.dta
			 firmlevel_TreatStatus.dta
			 Annual_sales.dta
			 shares_quarter_2016sales.dta
			 
Output: 	 ISV_reform_panel_quarter.dta
==============================================================================*/


/*******************************************************************************	
 1. Import VAT records and prepare dataset for manipulation
*******************************************************************************/

* Import VAT records and create period indicators
	use if year >= 2014 using "$databases/ISV_panel_vars.dta", clear
	
	if "$vat_freq" == "quarter" {
		gen quarter    = qofd(date)
		gen quarter_id = quarter(dofm(month))
	}
	else if {
		gen month_id = month(dofm(month))
	}
	

*Collapsing at the level of the baseline sample (monthly or quarterly)
	gen dummy_unrefunded = (unrefunded_balance_end_th > 0 & unrefunded_balance_end_th !=.)

	gcollapse (sum) net_payment_th total_withholding_th total_anticipated_th 	///
					total_revenue_th taxable_sales_th total_purchases_th 		///
					taxable_purchases_th withholding_cards_th exempted_purchases_th (max) dummy_unrefunded ///
			  (first) year (mean) unrefunded_balance_prev_th, by(id ${vat_freq} ${vat_freq}_id)
			  
			  
* Merge with treatment/control and set to missing the years that are not covered by sample
	merge m:1 id using "$databases/firmlevel_TreatStatus.dta"
	drop if _merge == 2
	drop _merge
	
	forvalues i = 0/4 {
		replace treat`i'_balanced_${vat_freq}_1418 = . if year == 2019
		replace treat`i'_balanced_${vat_freq}_1518 = . if year == 2014 | year == 2019 
		replace treat`i'_balanced_${vat_freq}_1519 = . if year == 2014
	}				  
			   

* Merge with true value of income
	merge m:1 id year using "$databases/Annual_sales.dta", keepusing(final_revenue_mil) keep(1 3)
	drop _merge		 
	gen final_revenue_th = final_revenue_mil * 1000								
	
	
* Merge with the share of sales across the year	
	merge m:1 id ${vat_freq}_id using "$databases/shares_${vat_freq}_2016sales.dta", keepusing(share_${vat_freq}) keep(1 3)
	drop _merge
	
	
****IMPORTANT EDIT: IF FIRM IS NEVER IN ANY BALANCED PANEL, JUST DROP IT BC IT WON'T BE USED IN ANY ANALYSIS
 egen any_balance = rowmax(balanced_quarter_1418 balanced_quarter_1419 balanced_quarter_1518 balanced_quarter_1519)
 keep if any_balance == 1
 
 
/*******************************************************************************	
 2. Build additional relevant outcomes for analysis
*******************************************************************************/

* Rename variables conveniently (so names are not that large after adding winsor suffix)	
	rename (total_withholding_th total_revenue_th taxable_sales_th total_purchases_th taxable_purchases_th unrefunded_balance_prev_th exempted_purchases_th withholding_cards_th) ///
		   (withholding revenue tax_sales purchases tax_purchases unref_balance exem_purchases withholding_cards)


* Effective tax rates, value added and post-reform periods
	egen tax_total  = rowtotal(net_payment_th withholding total_anticipated_th)	
	gen etr         = (tax_total / revenue) 
	gen value_added = tax_sales - tax_purchases
	gen post 		= (year >= 2017)
	
	
* Adjusting quarterly/monthly final revenue for normalization in 2016
	sort id year ${vat_freq}	
	gen   final_revenue_16_a = final_revenue_th if year == 2016
	gegen final_revenue_16_b = max(final_revenue_16_a), by(id)
	gen   final_revenue_16   = final_revenue_16_b * share_${vat_freq}
	
  
  
/*******************************************************************************	
 3. Normalization with respect to pre-reform sales in 2016 (Kennedy et. al 2023)
	and also winsorizing at different fractions of the distribution.
*******************************************************************************/

	local balance 1418 1419 1518 1519

* First, the dummy for unrefunded credits is replicated according to each of T&C groups, so it can be included in loops easily.
		forvalues i = 0/4 {
			foreach bal of local balance {
					gen byte dummy_unrefunded_n_`i'_`bal'_w999 = dummy_unrefunded if !missing(treat`i'_balanced_${vat_freq}_`bal')
					gen byte dummy_unrefunded_n_`i'_`bal'_w99  = dummy_unrefunded if !missing(treat`i'_balanced_${vat_freq}_`bal')
					gen byte dummy_unrefunded_n_`i'_`bal'_w95  = dummy_unrefunded if !missing(treat`i'_balanced_${vat_freq}_`bal')
			}
		}
		
		

* Secondly, continuous outcomes are normalized with sales.
* Winsorizing is made at the sample level, so it changes according to balancedness and T&C definitions.
* Be aware that value-added is also winsorized at the 0.1st fraction of observations due to outliers.
* Effective tax rates are not normalized with sales in 2016, because they're already normalized using period-by-period sales.


	foreach var of varlist withholding tax_total etr unref_balance revenue tax_sales purchases tax_purchases value_added withholding_cards exem_purchases {
		di "Winsorizing for variable: `var'"
		* Normalization using pre-reform quarterly sales
		if `var' == etr {
			gen `var'_n = `var'
		}
		else {
			gen `var'_n = `var' / final_revenue_16
		}
		
		* Winsorizing
		forvalues i = 0/4 {
			di in red "Winsorizing for variable: `var' and Treatment `i'"
			foreach bal of local balance {
			
				if `var' == value_added {																					
					winsor2 `var'_n if !missing(treat`i'_balanced_${vat_freq}_`bal'), cuts(0.1 99.9) suffix(_`i'_`bal'_w999)
					winsor2 `var'_n if !missing(treat`i'_balanced_${vat_freq}_`bal'), cuts(0.1 99)   suffix(_`i'_`bal'_w99)	
					winsor2 `var'_n if !missing(treat`i'_balanced_${vat_freq}_`bal'), cuts(0.1 95)   suffix(_`i'_`bal'_w95)									
				}
				else {									
					winsor2 `var'_n if !missing(treat`i'_balanced_${vat_freq}_`bal'), cuts(0 99.9) suffix(_`i'_`bal'_w999)
					winsor2 `var'_n if !missing(treat`i'_balanced_${vat_freq}_`bal'), cuts(0 99)   suffix(_`i'_`bal'_w99)	
					winsor2 `var'_n if !missing(treat`i'_balanced_${vat_freq}_`bal'), cuts(0 95)   suffix(_`i'_`bal'_w95)		
				}	
			}
		}				   	
    }


	
/*******************************************************************************	
 4. Adding labels, and saving final dataset
*******************************************************************************/

* Adding labels to prefix of the variables only
	label var tax_sales         "Taxable Sales" 
	label var tax_total 		"Total Remitted Taxes" 
	label var etr   			"Effective Tax Rate" 
	label var dummy_unrefunded  "Pr(Unrefunded Balance = 1)"
	label var unref_balance     "Stock Unrefunded Balance"
	label var withholding       "Total Ammount Withheld" 
	label var revenue 	        "Total Revenue"
	label var purchases   		"Total Purchases"
	label var tax_purchases 	"Taxable Purchases"
	label var value_added 		"Value Added"
	label var exem_purchases    "Exempt purchases"
	label var withholding_cards "DCC Withholding"
	
	
* Let's keep variables of interest only
	keep id ${vat_freq} year post withholding* tax_total* etr* unref_balance* revenue* tax_sales* purchases* ///
		 tax_purchases* value_added* dummy_unrefunded* exem_purchases* withholding_cards*
	order id ${vat_freq} year post, first
	
	
* Saving working dataset, ready for estimations
	compress
	save "$databases/ISV_reform_panel_${vat_freq}.dta", replace

