/*=============================================================================
Name: 		 5c_Descriptives_Reform_Table.do

Description: This do file produces Table 3 with summary statistics in 2016 for 
			 the baseline sample included in the empirical analysis of the reform.

Input: 	     ISV_reform_panel.dta
			 firmlevel_TreatStatus.dta
			 ISRPN_workingdatabase.dta
			 ISRPJ_workingdatabase.dta
			 Annual_sales.dta
			 Firm_traits.dta
			 
Output: 	 summary.tex
==============================================================================*/


	* Import VAT records and merge with treatment/control status
	use "$databases/ISV_panel_vars.dta", clear
	keep if year == 2016
	
	merge m:1 id using "$databases/firmlevel_TreatStatus.dta", keepusing(treat0_balanced_${vat_freq}_${vat_since}${vat_to} treat0_balanced_${vat_freq}_${isr_since}${isr_to}) keep(1 3)
	drop _merge
	
	
	* Let's keep firms in the baseline estimates for ISR and ISV only
	keep if !missing(treat0_balanced_${vat_freq}_${isr_since}${isr_to}) | !missing(treat0_balanced_${vat_freq}_${vat_since}${vat_to})

	gcollapse (sum) total_revenue_th taxable_sales_th gross_liability_th credits_th net_liability_th  total_withholding_th ///
	          net_payment_th withholding_cards_th withholding_govt_th withholding_large_th total_anticipated_th exports_th ///
			  (max) dummy_with_cards unique_firm max_tarj dummy_with_cards_n change_balance_year endyear_balance positive_balance ///
			  (first) treat0_balanced_${vat_freq}_${isr_since}${isr_to} treat0_balanced_${vat_freq}_${vat_since}${vat_to} year, by(id) ///
	 labelformat(#sourcelabel#)
	 
	* Merge with true value of income
	merge 1:1 id year using "$databases/Annual_sales.dta", keepusing(final_revenue_mil)
	drop if _merge == 2
	drop _merge
	
	* Merge with firm's traits
	merge m:1 id using "$databases/Firm_traits.dta", gen(mergeTraits)
	keep if mergeTraits != 2
	
	* Building additional characteristics of interest
	gen unit = 1
	gen corporate = (tipo == 1)
	gen small 	  = (size == 3)
	gen retail 		  		   = (activity_sector == 6)
	gen manufacturing 		   = (activity_sector == 2)
	gen wholesale     		   = (activity_sector == 5)
	gen services      		   = inrange(activity_sector,7,11) 
	gen dummy_with_cards_panel = dummy_with_cards
	gen positive_balance_panel = positive_balance
	gen exporter 			   = (exports_th > 0 & !mi(exports_th))
	gen dummy_large 		   = (withholding_large_th > 0 & !mi(withholding_large_th))
	gen dummy_govt			   = (withholding_govt_th > 0  & !mi(withholding_govt_th))
	 
	 * Merge with income tax records		  
	merge 1:1 id year using "$databases/ISRPN_workingdatabase.dta", keep(1 3) gen(mergePN)
	merge 1:1 id year using  "$databases/ISRPJ_workingdatabase.dta", keep(1 3 4 5) gen(mergePJ) update replace
	
	gen ppe_gross2 = cond(tipo == 1 & !missing(ppe_gross1_mil) & ppe_gross1_mil > 0, ppe_gross1_mil, ///
					 cond(tipo == 2 & !missing(ppe_gross_mil) & ppe_gross_mil > 0, ppe_gross_mil, 0))	
					  
	gen ppe_net2 = cond(tipo == 1 & !missing(ppe_net1_mil) & ppe_net1_mil > 0, ppe_net1_mil, ///
				   cond(tipo == 2 & !missing(ppe_net_mil) & ppe_net_mil > 0, ppe_net_mil, 0))	
				   
	gen inv_gross2 = cond(tipo == 1 & !missing(gross_inv1_mil) & gross_inv1_mil > 0, gross_inv1_mil, ///
					 cond(tipo == 2 & !missing(gross_inv_mil) & gross_inv_mil > 0, gross_inv_mil, 0))	
					 
	gen inv_net2 = cond(tipo == 1 & !missing(net_inv1_mil) & net_inv1_mil > 0, net_inv1_mil, ///
				   cond(tipo == 2 & !missing(net_inv_mil) & net_inv_mil > 0, net_inv_mil, 0))
		
	
	global isr current_assets_mil noncurrent_assets_mil current_liab_mil noncurrent_liab_mil ppe_gross2 ///
			   ppe_net2 inv_gross2 inv_net2 cash_stock_mil labor_costs_mil pre_tax_profits_mil after_tax_profits_mil
						
	foreach var of varlist $isr {
		gen `var'_th = `var' * 1000
	}					

	rename (current_assets_mil_th noncurrent_assets_mil_th current_liab_mil_th noncurrent_liab_mil_th cash_stock_mil_th labor_costs_mil_th pre_tax_profits_mil_th after_tax_profits_mil_th) ///
		   (current_assets_th noncurrent_assets_th current_liab_th noncurrent_liab_th cash_stock_th labor_costs_th pre_tax_profits_th after_tax_profits_th)
		   
	* Additional outcomes
	gen filed_incometax = (mergePN != 1 | mergePJ!=1)
	gen share_unrefunded = endyear_balance/taxable_sales_th	
	gen treat = min(treat0_balanced_${vat_freq}_${isr_since}${isr_to}, treat0_balanced_${vat_freq}_${vat_since}${vat_to})
	replace positive_balance_panel = positive_balance_panel*100
	replace dummy_with_cards_panel = dummy_with_cards_panel*100
	
	* Adding labels 
	lab var current_assets_th 	 "Current assets (L1,000s)"
	lab var noncurrent_assets_th "Non-current assets (L1,000s)"
	lab var current_liab_th		 "Current liabilities (L1,000s)"
	lab var noncurrent_liab_th 	 "Non-current liabilities (L1,000s)"
	lab var ppe_gross2_th		 "Gross fixed assets (L1,000s)"
	lab var ppe_net2_th			 "Net fixed assets (L1,000s)"
	lab var inv_gross2_th 		 "Gross investment (L1,000s)"
	lab var inv_net2_th 		 "Net investment (L1,000s)"
	lab var cash_stock_th 		 "Cash stock (L1,000s)"
	lab var labor_costs_th 		 "Wage bill (L1,000s)"
	lab var pre_tax_profits_th   "Pre-tax profits (L1,000s)"
	lab var after_tax_profits_th "After-tax profits (L1,000s)"					
	lab var share_unrefunded 		"Unrefunded stock (\% taxable sales)"
	lab var corporate        		"Corporation"
	lab var small			 		"Official size: small"
	lab var retail        	 		"Sector: Retail"
	lab var manufacturing 	 		"Sector: Manufacturing"
	lab var wholesale        		"Sector: Wholesale"
	lab var services        		"Sector: Services"
	lab var filed_incometax  		"Filed yearly income tax"
	lab var dummy_with_cards_panel 	"Claims Digital Payment withholding (\%)"
	lab var positive_balance_panel 	"Claims positive unrefunded balance (\%)"
	lab var withholding_cards_th   	"Digital payment withholding (L 1,000s)"
	lab var change_balance_year  	"Yearly change in unrefunded balance (L1,000s)"
	lab var endyear_balance  		"Unrefunded balance in December (L1,000s)"
	lab var exporter				"Exporter (\%)"
	lab var dummy_large			    "Withheld by large taxpayers (\%)"
	lab var dummy_govt				"Withheld by government (\%)"
	
	
	* Defining variables according to balancedness, then build table
	global traits corporate small retail manufacturing wholesale services filed_incometax exporter
	
	global vat_outcomes total_revenue_th taxable_sales_th gross_liability_th credits_th net_liability_th total_withholding_th ///
		                withholding_cards_th withholding_govt_th withholding_large_th   ///
						net_payment_th dummy_with_cards_panel withholding_cards_th positive_balance_panel endyear_balance
						
	global isr_outcomes current_assets_th noncurrent_assets_th current_liab_th noncurrent_liab_th ppe_gross2_th ///
			   ppe_net2_th inv_gross2_th inv_net2_th cash_stock_th labor_costs_th pre_tax_profits_th after_tax_profits_th

	cap est drop *
	eststo traits_all: qui estpost summ $traits, d
	eststo traits_0:   qui estpost summ $traits if treat == 0, d
	eststo traits_1:   qui estpost summ $traits if treat == 1, d
	
	eststo vat_all:	qui estpost summ $vat_outcomes if !missing(treat0_balanced_${vat_freq}_${vat_since}${vat_to}), d
	eststo vat_0:   qui estpost summ $vat_outcomes if treat0_balanced_${vat_freq}_${vat_since}${vat_to} == 0, d
	eststo vat_1:   qui estpost summ $vat_outcomes if treat0_balanced_${vat_freq}_${vat_since}${vat_to} == 1, d
	
	eststo isr_all: qui estpost summ $isr_outcomes if !missing(treat0_balanced_${vat_freq}_${isr_since}${isr_to}), d
	eststo isr_0: 	qui estpost summ $isr_outcomes if treat0_balanced_${vat_freq}_${isr_since}${isr_to} == 0, d
	eststo isr_1: 	qui estpost summ $isr_outcomes if treat0_balanced_${vat_freq}_${isr_since}${isr_to} == 1, d

	esttab traits_all traits_0 traits_1 using "$tables/summary.tex", replace collabels("Mean" "SD") ///
	label booktabs f alignment(r) compress nonumbers nonotes nomtitles noobs ///
	cells("mean(pattern(1 1 1) fmt(2)) .")  ///
	mgroups("\textbf{Pooled Sample}" "\textbf{Low Usage Firms}" "\textbf{High Usage Firms}", span prefix(\multicolumn{@span}{c}{) ///
	suffix(}) pattern(1 1 1) erepeat(\cmidrule(lr){@span})) refcat(corporate "\textbf{Panel A: Firm's Traits}  & & & & & & \\", nolabel)
	
	esttab vat_all vat_0 vat_1 using "$tables/summary.tex", append label booktabs alignment(r) nonum nomtitle collabels(none) f  ///
	cells("mean(pattern(1 1 1) fmt(%12.0fc)) sd(pattern(1 1 1) fmt(%12.0fc) par)") substitute(_ _) ///
	refcat(total_revenue_th "\textbf{Panel B: Outcomes for analysis of \autoref{sec:compliance}} & & & & & & \\  \addlinespace \emph{VAT descriptives}" ///
	dummy_with_cards_panel " \addlinespace \emph{Withholding}" positive_balance_panel " \addlinespace \emph{Unrefunded credit}", nolabel)
	
	esttab isr_all isr_0 isr_1 using "$tables/summary.tex", append label booktabs alignment(r) nonum nomtitle collabels(none) f  ///
	cells("mean(pattern(1 1 1) fmt(%12.0fc)) sd(pattern(1 1 1) fmt(%12.0fc) par)") substitute(_ _) ///
	refcat(current_assets_th "\textbf{Panel C: Outcomes for analysis of \autoref{sec:firms_performance}} & & & & & & \\  \addlinespace \emph{Balance sheet breakdown}" ///
	ppe_gross2_th " \addlinespace \emph{Investment}" cash_stock_th " \addlinespace \emph{Additional outcomes}", nolabel) postfoot(\bottomrule)
	
	
