/*==============================================================================
Name: 		 6a_Analysis_Reform_ISR.do

Description: This do file runs DiD models and produces figures 6, 7, A13, and A14. 
			 Also produces tables 5 and 6.

Input: 	     ISR_reform_panel.dta
			 firmlevel_TreatStatus.dta
			 heterogeneity_traits.dta
			 Annual_sales.dta
			 
Output: 	 balance_prepost1.tex
			 investment_prepost1.tex
			 performance_prepost1.tex
			 mean1_after_tax_profits.pdf
			 mean1_pre_tax_profits.pdf
			 mean1_labor_costs.pdf
			 mean1_cash_stock.pdf
			 mean1_prob_inv_net.pdf
			 mean1_prob_inv_gross.pdf
			 mean1_inv_net2.pdf
			 mean1_inv_gross2.pdf
			 mean1_ppe_net2.pdf
			 mean1_ppe_gross2.pdf
			 mean1_noncurrent_liab.pdf
			 mean1_current_liab.pdf
			 mean1_current_assets.pdf
			 mean1_noncurrent_assets.pdf
			 mean1_deduction.pdf
			 did1_after_tax_profits.pdf
			 did1_pre_tax_profits.pdf
			 did1_labor_costs.pdf
			 did1_cash_stock.pdf
			 did1_prob_inv_net.pdf
			 did1_prob_inv_gross.pdf
			 did1_inv_net2.pdf
			 did1_inv_gross2.pdf
			 did1_ppe_net2.pdf
			 did1_ppe_gross2.pdf
			 did1_noncurrent_liab.pdf
			 did1_current_liab.pdf
			 did1_noncurrent_assets.pdf
			 did1_current_assets.pdf
			 did1_deduction.pdf
==============================================================================*/


/*******************************************************************************	
 1. Import income tax records and prepare dataset for manipulation
*******************************************************************************/
	
* Run program for import data and prepare it before analysis
	import_incometax_data
	
* Let's keep only firms in baseline sample 
	keep if treat0_${panel_isr} != . & inrange(year, 20${isr_since}, 20${isr_to})

	

/*******************************************************************************	
 2. $figures 9, 10, and 11 with dynamic DiD estimations using baseline sample 
*******************************************************************************/		
	
* Saving variable's label before collapsing data so then we just paste it in the $figures
	foreach var of varlist $var_balance $var_investment $var_performance {		
		local l`var': variable label `var'
			if `"`l`var''"' == "" {
				local l`var' "`var'"
			}
    }
	
	
* $figures with raw means
	preserve
		gcollapse (mean) ${isr_collapse}, by(year treat0_${panel_isr})
		
		foreach var of varlist $var_balance $var_investment $var_performance {
			label var `var' `"`l`var''"'
			local lab: variable label `var'	
			
			qui sum `var'_n_0_${isr_since}${isr_to}_w95 if (year >= 2014 & year <= 2016 & treat0_${panel_isr} == 0)
			loc avg_c = `r(mean)'
			loc max_c = `r(max)'
			loc min_c = `r(min)'
			qui sum `var'_n_0_${isr_since}${isr_to}_w95 if (year >= 2014 & year <= 2016 & treat0_${panel_isr} == 1)
			loc avg_t = `r(mean)'
			loc max_t = `r(max)'
			loc min_t = `r(min)'
						
			if (`avg_t'>`avg_c') {
				if `avg_t' < 0.1 {
					loc y_ax_c = `min_c' - 0.002
					loc y_ax_t = `max_t' + 0.002
				}
				else {
					loc y_ax_c = `min_c' - 0.005
					loc y_ax_t = `max_t' + 0.005				
				}
			}
			else {
				if `avg_c' < 0.1 {
					loc y_ax_c = `max_c' + 0.002
					loc y_ax_t = `min_t' - 0.002	
				}
				else {
					loc y_ax_c = `max_c' + 0.005
					loc y_ax_t = `min_t' - 0.005				
				}
			}
			
			twoway (scatter `var'_n_0_${isr_since}${isr_to}_w95 year if treat0_${panel_isr} == 0, c(l) mcolor(dkorange%50) lc(dkorange%50) msymbol(D)) ///
				   (scatter `var'_n_0_${isr_since}${isr_to}_w95 year if treat0_${panel_isr} == 1, c(l) mcolor(dknavy) lc(dknavy) lw(medthick)), ///
				   tline(2016.5, lp(dash) lw(vthin) lc(black)) ytitle("`lab'") xtitle("Year") $graphopt legend(off)  ///
				   ylabel(#8, angle(0)) ttext(`y_ax_c' 2015 "Low usage", color(dkorange%50)) ttext(`y_ax_t' 2015 "High usage", color(dknavy))
			graph export "$figures/mean1_`var'.pdf", replace 
		}
	restore	


* $figures with event-study coefficients	
	foreach var of varlist $var_balance $var_investment $var_performance {
		local lab: variable label `var'
		
		qui reghdfe `var'_n_0_${isr_since}${isr_to}_w95 ib0.treat0_${panel_isr}##ib2016.year, a(id year#activity_sector#quantile0_${vat_freq}_${isr_since}${isr_to}) cluster(id)
		
		coefplot, xline(3.5, lcolor(black) lp(dash) lw(vthin)) mcolor(blue) ciopts(recast(rcap) lcolor(gs8%60)) legend(off) yscale(titlegap(1)) $graphopt 			///
			 keep(1.treat0_${panel_isr}#*year*) yline(0, lcolor(black) lp(dash)) omitted vertical baselevels ylabel(, angle(0)) ytitle("Coef: `lab'") ///
			 coeflabel(1.treat0_${panel_isr}#2014.year = "2014" 1.treat0_${panel_isr}#2015.year = "2015" 1.treat0_${panel_isr}#2016.year = "2016"    ///
			 1.treat0_${panel_isr}#2017.year = "2017" 1.treat0_${panel_isr}#2018.year = "2018" 1.treat0_${panel_isr}#2019.year = "2019", labsize(small)) 
		graph export "$figures/did1_`var'.pdf", replace	 
	}


	
/*******************************************************************************	
 3. $tables 6, 7, and 8 with pooled pre-post DiD estimations using baseline sample 
*******************************************************************************/

* Balance sheet breakdown: Table 6
	cap est drop *
	foreach var of varlist $var_balance {
		
		summ `var'_n_0_${isr_since}${isr_to}_w95 if year == 2016
		loc mean_dv = `r(mean)'
		
		eststo: reghdfe `var'_n_0_${isr_since}${isr_to}_w95 post##treat0_${panel_isr}, a(id year#activity_sector#quantile0_${vat_freq}_${isr_since}${isr_to}) cluster(id)
		estadd scalar mean_dv `mean_dv'
		estadd scalar n_firms = e(N_clust)
		estadd loc firm_fe "Yes"
		estadd loc year_industry_fe "Yes"
	}

	esttab using "$tables/balance_prepost1.tex", replace booktabs f se(2) b(3) ///
		keep(1.post#1.treat* _cons) coeflabels(1.post#1.treat0_${panel_isr} "High usage $\times$ Post" _cons "Constant") postfoot(\bottomrule) ///
		stats(N n_firms r2 mean_dv firm_fe year_industry_fe, labels(Observations "\# Firms" R-Squared "Mean Dep Var 2016" "Firm FE?" "Year-Industry-Size FE?") ///
		fmt(%12.0fc %12.0fc %12.2fc)) star(* 0.10 ** 0.05 *** 0.01) mtitles("Current Assets" "Non-Current Assets" "Current Liabilities" "Non-Current Liabilities") 


* Outcomes on physical assets and investment: Table 7
	cap est drop *
	foreach var of varlist $var_investment {
		
		summ `var'_n_0_${isr_since}${isr_to}_w95 if year == 2016
		loc mean_dv = `r(mean)'
		
		eststo: reghdfe `var'_n_0_${isr_since}${isr_to}_w95 post##treat0_${panel_isr}, a(id year#activity_sector#quantile0_${vat_freq}_${isr_since}${isr_to}) cluster(id)
		estadd scalar mean_dv `mean_dv'
		estadd scalar n_firms = e(N_clust)
		estadd loc firm_fe "Yes"
		estadd loc year_industry_fe "Yes"
	}

	esttab using "$tables/investment_prepost1.tex", replace booktabs f se(2) b(3) star(* 0.10 ** 0.05 *** 0.01) ///
		keep(1.post#1.treat* _cons) coeflabels(1.post#1.treat0_${panel_isr} "High usage $\times$ Post" _cons "Constant")  postfoot(\bottomrule) ///
		stats(N n_firms r2 mean_dv firm_fe year_industry_fe, labels(Observations "\# Firms" R-Squared "Mean Dep Var 2016" "Firm FE?" "Year-Industry-Size FE?") ///
		fmt(%12.0fc %12.0fc %12.2fc)) mtitles("Net Investment" "Pr(Net investment > 0)" "Net PPE" "Gross Investment" "Pr(Gross investment > 0)" "Gross PPE") 

		
* Cash, wages, and profits: Table 8
	cap est drop *	
	foreach var of varlist $var_performance {
		
		summ `var'_n_0_${isr_since}${isr_to}_w95 if year == 2016
		loc mean_dv = `r(mean)'
		
		eststo: reghdfe `var'_n_0_${isr_since}${isr_to}_w95 post##treat0_${panel_isr}, a(id year#activity_sector#quantile0_${vat_freq}_${isr_since}${isr_to}) cluster(id)
		estadd scalar mean_dv `mean_dv'
		estadd scalar n_firms = e(N_clust)
		estadd loc firm_fe "Yes"
		estadd loc year_industry_fe "Yes"			
	}

	esttab using "$tables/performance_prepost1.tex", replace booktabs f se(2) b(3) ///
		keep(1.post#1.treat* _cons) coeflabels(1.post#1.treat0_${panel_isr} "High usage $\times$ Post" _cons "Constant")  postfoot(\bottomrule) ///
		stats(N n_firms r2 mean_dv firm_fe year_industry_fe, labels(Observations "\# Firms" R-Squared "Mean Dep Var 2016" "Firm FE?" "Year-Industry-Size FE?") ///
		fmt(%12.0fc %12.0fc %12.2fc)) star(* 0.10 ** 0.05 *** 0.01) mtitles("Cash" "Wage Bill" "Pre-Tax Profits" "After-Tax Profits") 
		
		
