/*==============================================================================
Name: 		 6a_Analysis_Reform_ISV.do

Description: This do-file runs DiD models and produces Figures 4, 5, A11, and A12. 
			 Also produces Tables 3 and 4.

Input: 	     ISV_reform_panel_quarter.dta
			 firmlevel_TreatStatus.dta
			 heterogeneity_traits.dta
			 Annual_sales.dta
			 
Output: 	 first_stage_prepost1.tex
			 second_stage_prepost1.tex
			 mean1_value_added.pdf
			 mean1_tax_total.pdf
			 mean1_etr.pdf
			 mean1_dummy_unrefunded.pdf
			 mean1_unref_balance.pdf
			 mean1_revenue.pdf
			 mean1_tax_sales.pdf
			 mean1_purchases.pdf
			 mean1_tax_purchases.pdf
			 mean1_exem_purchases.pdf
			 mean1_withholding_cards.pdf
			 mean1_withholding.pdf
			 did1_value_added.pdf
			 did1_tax_total.pdf
			 did1_etr.pdf
			 did1_dummy_unrefunded.pdf
			 did1_unref_balance.pdf
			 did1_revenue.pdf
			 did1_tax_sales.pdf
			 did1_purchases.pdf
			 did1_tax_purchases.pdf
			 did1_exem_purchases.pdf
			 did1_withholding_cards.pdf
			 did1_withholding.pdf
==============================================================================*/

	
/*******************************************************************************	
 1. Import VAT records and prepare dataset for manipulation
*******************************************************************************/
	
* Run program for import data and prepare it before analysis
	import_vat_data
	
* Let's keep only firms in baseline sample 
	keep if treat0_${panel_vat} != . & inrange(year, 20${vat_since}, 20${vat_to})

	

/*******************************************************************************	
 2. Figures 7 and 8 with estimations for VAT outcomes using baseline sample 
*******************************************************************************/
	
* Saving variable's labels before collapsing data so then we just paste it in the $figures
	foreach var of varlist $var_compliance $var_outcomes {						
		local l`var': variable label `var'
			if `"`l`var''"' == "" {
				local l`var' "`var'"
			}
    }
	
	
* Figures with raw means
	preserve
		gcollapse (mean) ${vat_collapse}, by(quarter treat0_${panel_vat})
		
		foreach var of varlist $var_compliance $var_outcomes {
			label var `var' `"`l`var''"'
			local lab: variable label `var'	
			
			qui sum `var'_n_0_${vat_since}${vat_to}_w95 if (quarter >= 222 & quarter <= 224 & treat0_${panel_vat} == 0)
			loc avg_c = `r(mean)'
			loc max_c = `r(max)'
			loc min_c = `r(min)'
			qui sum `var'_n_0_${vat_since}${vat_to}_w95 if (quarter >= 222 & quarter <= 224 & treat0_${panel_vat} == 1)
			loc avg_t = `r(mean)'
			loc max_t = `r(max)'
			loc min_t = `r(min)'
			
			if (`avg_t'>`avg_c') {
				if (`avg_t' < 0.15) {
					loc y_ax_c = `min_c' - 0.004
					loc y_ax_t = `max_t' + 0.004
				}
				else {
					loc y_ax_c = `min_c' - 0.05
					loc y_ax_t = `max_t' + 0.05			
				}
			}
			else {
				if (`avg_c' < 0.15) {
					loc y_ax_c = `max_c' + 0.004
					loc y_ax_t = `min_t' - 0.004	
				}
				else {
					loc y_ax_c = `max_c' + 0.05
					loc y_ax_t = `min_t' - 0.05				
				}
			}
			
			loc x_line = tq(2016q4)+0.5
			
			twoway (scatter `var'_n_0_${vat_since}${vat_to}_w95 quarter if treat0_${panel_vat} == 0, c(l) mcolor(dkorange%50) lc(dkorange%50) msymbol(D)) ///
				   (scatter `var'_n_0_${vat_since}${vat_to}_w95 quarter if treat0_${panel_vat} == 1, c(l) mcolor(dknavy) lc(dknavy) lw(medthick)), ///
				   xline(`x_line', lp(dash) lw(vthin) lcolor(black)) ytitle("`lab'") $graphopt legend(off) yscale(range(0, .)) ylabel(#10, angle(0)) ///
				   ttext(`y_ax_c' 223 "Low usage", color(dkorange%50)) ttext(`y_ax_t' 223 "High usage", color(dknavy)) xlabel(#8, labsize(small) angle(45))
			graph export "$figures/mean1_`var'.pdf", replace 
		}
	restore

	
* Figures with event-study coefficients	
 	foreach var of varlist $var_compliance  $var_outcomes {
		local lab: variable label `var'
		
		qui reghdfe `var'_n_0_${vat_since}${vat_to}_w95 ib0.treat0_${panel_vat}##ib227.quarter, a(id quarter#activity_sector#quantile0_${vat_freq}_${vat_since}${vat_to}) cluster(id)
		
		coefplot, keep(1.treat0_${panel_vat}*#*quarter*) mcolor(blue) omitted vertical baselevels $graphopt legend(off) ylabel(, angle(0))				   ///
			 coeflabel(1.treat0_${panel_vat}#220.quarter = "2015q1" 1.treat0_${panel_vat}#221.quarter = " " 										   ///
			 1.treat0_${panel_vat}#222.quarter = "2015q3" 1.treat0_${panel_vat}#223.quarter = " " 1.treat0_${panel_vat}#224.quarter = "2016q1" ///
			 1.treat0_${panel_vat}#225.quarter = " " 1.treat0_${panel_vat}#226.quarter = "2016q3" 1.treat0_${panel_vat}#227.quarter = " " ///
			 1.treat0_${panel_vat}#228.quarter = "2017q1" 1.treat0_${panel_vat}#229.quarter = " " 1.treat0_${panel_vat}#230.quarter = "2017q3" ///
			 1.treat0_${panel_vat}#231.quarter = " " 1.treat0_${panel_vat}#232.quarter = "2018q1" 1.treat0_${panel_vat}#233.quarter = " " ///
			 1.treat0_${panel_vat}#234.quarter = "2018q3" 1.treat0_${panel_vat}#235.quarter = " ", labsize(small) angle(45))						   ///
			 ciopts(recast(rcap) lcolor(gs8%60)) ytitle("Coef: `lab'") yscale(titlegap(1)) xline(8.5, lp(dash) lcolor(black) lw(vthin)) ///
			 yline(0, lcolor(black) lp(dash)) 
		graph export "$figures/did1_`var'.pdf", replace
	}


	
/*******************************************************************************	
 3. Tables 4 and 5 with estimations for VAT outcomes using baseline sample 
*******************************************************************************/	

* Compliance effects of the reform: Table 4
	cap est drop *
	
	foreach var of varlist $var_compliance1 {

			summ `var'_n_0_${vat_since}${vat_to}_w95 if year == 2016
			loc mean_dv = `r(mean)'
			
			eststo: reghdfe `var'_n_0_${vat_since}${vat_to}_w95 post##treat0_${panel_vat}, a(id quarter#activity_sector#quantile0_${vat_freq}_${vat_since}${vat_to}) cluster(id)
			estadd scalar mean_dv `mean_dv'
			estadd scalar n_firms = e(N_clust)
			estadd loc firm_fe "Yes"
			estadd loc qtr_industry_fe "Yes"
	}

	esttab using "$tables/first_stage_prepost1.tex", replace booktabs f se(2) b(3) star(* 0.10 ** 0.05 *** 0.01) ///
		keep(1.post#1.treat* _cons) coeflabels(1.post#1.treat0_${panel_vat} "High usage $\times$ Post" _cons "Constant") postfoot(\bottomrule) ///
		stats(N n_firms r2 mean_dv firm_fe qtr_industry_fe, labels(Observations "\# Firms" R-Squared "Mean Dep Var 2016" "Firm FE?" "Quarter-Industry-Size FE?") ///
		fmt(%12.0fc %12.0fc %12.2fc)) mtitles("Total amount withheld" "Remitted taxes" "Effective tax rate" "Pr(Unrefunded Balance = 1)" "Stock unrefunded balance") 	

		
* Additional VAT outcomes: Table 5 
	cap est drop *
	foreach var of varlist $var_outcomes1 {
	

		summ `var'_n_0_${vat_since}${vat_to}_w95 if year == 2016
		loc mean_dv = `r(mean)'
		
		eststo: reghdfe `var'_n_0_${vat_since}${vat_to}_w95 post##treat0_${panel_vat}, a(id quarter#activity_sector#quantile0_${vat_freq}_${vat_since}${vat_to}) cluster(id)
		estadd scalar mean_dv `mean_dv'
		estadd scalar n_firms = e(N_clust)
		estadd loc firm_fe "Yes"
		estadd loc qtr_industry_fe "Yes"
	}
	
	esttab using "$tables/second_stage_prepost1.tex", replace booktabs f se(2) b(3)  ///
			keep(1.post#1.treat* _cons) coeflabels(1.post#1.treat0_${panel_vat} "High usage $\times$ Post" _cons "Constant") ///
			stats(N n_firms r2 mean_dv firm_fe qtr_industry_fe, labels(Observations "\# Firms" R-Squared "Mean Dep Var 2016" "Firm FE?" "Quarter-Industry-Size FE?") ///
			fmt(%12.0fc %12.0fc %12.2fc)) star(* 0.10 ** 0.05 *** 0.01) mtitles("Taxable sales" "Taxable purchases" "Value added") postfoot(\bottomrule) 
	
	
