/*==============================================================================
Name: 		 6b_Robustness_ISR.do

Description: Conducts robustness checks running regression models on different
			 samples and alternative winsorizing using balance sheets. 
			 Produces tables A3, A5, and A6.

Input: 	     ISR_reform_panel.dta
			 firmlevel_TreatStatus.dta
			 heterogeneity_traits.dta
			 Annual_sales.dta
			 
Output: 	 performance_robustness1.tex
			 performance_robustness3.tex
==============================================================================*/


/*******************************************************************************	
 1. Import income tax records and prepare dataset for manipulation
*******************************************************************************/
	
* Run program for import data and prepare it before analysis
	import_incometax_data
	

	
/*******************************************************************************	
 2. Table 10 with robustness checks for balance sheet outcomes changing 
	balancedness and winsorized at different thresholds
*******************************************************************************/	

* Difference-in-Differences estimations
* Notice that probability of gross/net investment only changes across sample, not winsorizing.
* This is because is a probability (taking values of 1 or 0), no need to winsorize.

cap est drop *
local balance 1419 1418 1518 1519

* Header of the table
	foreach b of local balance {
		di in red "Regressions for net investment, sample `b'"
		eststo: qui reghdfe inv_net2_n_0_`b'_w95  post##treat0_balanced_${vat_freq}_`b', a(id year#activity_sector#quantile0_${vat_freq}_`b') cluster(id)
		eststo: qui reghdfe inv_net2_n_0_`b'_w99  post##treat0_balanced_${vat_freq}_`b', a(id year#activity_sector#quantile0_${vat_freq}_`b') cluster(id)
		eststo: qui reghdfe inv_net2_n_0_`b'_w999 post##treat0_balanced_${vat_freq}_`b', a(id year#activity_sector#quantile0_${vat_freq}_`b') cluster(id)
	}
	
	esttab using "$tables/performance_robustness1.tex", replace booktabs noobs f se(2) b(3) keep(1.post#1.treat0*) star(* 0.10 ** 0.05 *** 0.01) ///
		   rename(1.post#1.treat0_balanced_${vat_freq}_1418 1.post#1.treat0_balanced_${vat_freq}_1419 1.post#1.treat0_balanced_${vat_freq}_1518 1.post#1.treat0_balanced_${vat_freq}_1419 ///
		   1.post#1.treat0_balanced_${vat_freq}_1519 1.post#1.treat0_balanced_${vat_freq}_1419) coeflabel(1.post#1.treat0_balanced_${vat_freq}_1419 "Net investment") 					  ///
		   mgroups("Balanced 2014q1 - 2019q4" "Balanced 2014q1 - 2018q4" "Balanced 2015q1 - 2018q4" "Balanced 2015q1 - 2019q4", span prefix(\multicolumn{@span}{c}{) suffix(}) 			  ///
		   pattern(1 0 0  1 0 0  1 0 0  1 0 0) erepeat(\cmidrule(lr){@span})) mtitles("95th" "99th" "99.9th" "95th" "99th" "99.9th" "95th" "99th" "99.9th" "95th" "99th" "99.9th")

* Body of the table
	cap est drop *	   
	foreach var of varlist prob_inv_net ppe_net2 cash_stock labor_costs {
						   	
		local lab: variable label `var'
		
		foreach b of local balance {
			di in red "Regressions for `var', sample `b'"
			eststo: qui reghdfe `var'_n_0_`b'_w95  post##treat0_balanced_${vat_freq}_`b', a(id year#activity_sector#quantile0_${vat_freq}_`b') cluster(id)
			eststo: qui reghdfe `var'_n_0_`b'_w99  post##treat0_balanced_${vat_freq}_`b', a(id year#activity_sector#quantile0_${vat_freq}_`b') cluster(id)
			eststo: qui reghdfe `var'_n_0_`b'_w999 post##treat0_balanced_${vat_freq}_`b', a(id year#activity_sector#quantile0_${vat_freq}_`b') cluster(id)	
	    }
	
	esttab using "$tables/performance_robustness1.tex", append booktabs nonumbers nomtitles noobs nolines f se(2) b(3) keep(1.post#1.treat0*) ///
		   rename(1.post#1.treat0_balanced_${vat_freq}_1418 1.post#1.treat0_balanced_${vat_freq}_1419 1.post#1.treat0_balanced_${vat_freq}_1518 1.post#1.treat0_balanced_${vat_freq}_1419 ///
		   1.post#1.treat0_balanced_${vat_freq}_1519 1.post#1.treat0_balanced_${vat_freq}_1419) coeflabel(1.post#1.treat0_balanced_${vat_freq}_1419 "`lab'") star(* 0.10 ** 0.05 *** 0.01)
		   
	cap est drop *	
	}   
	
* Bottom of the table
	foreach b of local balance {
			di in red "Regressions for pre tax profits, sample `b'"
			eststo: qui reghdfe pre_tax_profits_n_0_`b'_w95 post##treat0_balanced_${vat_freq}_`b', a(id year#activity_sector#quantile0_${vat_freq}_`b') cluster(id)
			estadd scalar n_firms = e(N_clust)
			estadd loc firm_fe "Yes"
			estadd loc year_industry_fe "Yes"
			
			eststo: qui reghdfe pre_tax_profits_n_0_`b'_w99  post##treat0_balanced_${vat_freq}_`b', a(id year#activity_sector#quantile0_${vat_freq}_`b') cluster(id)
			estadd scalar n_firms = e(N_clust)
			estadd loc firm_fe "Yes"
			estadd loc year_industry_fe "Yes"
			
			eststo: qui reghdfe pre_tax_profits_n_0_`b'_w999  post##treat0_balanced_${vat_freq}_`b', a(id year#activity_sector#quantile0_${vat_freq}_`b') cluster(id)
			estadd scalar n_firms = e(N_clust)
			estadd loc firm_fe "Yes"
			estadd loc year_industry_fe "Yes"		
	}
		   
	esttab using "$tables/performance_robustness1.tex", append booktabs nonumbers nomtitles noobs f se(2) b(3) keep(1.post#1.treat0*) star(* 0.10 ** 0.05 *** 0.01) ///
		   rename(1.post#1.treat0_balanced_${vat_freq}_1418 1.post#1.treat0_balanced_${vat_freq}_1419 1.post#1.treat0_balanced_${vat_freq}_1518 1.post#1.treat0_balanced_${vat_freq}_1419 ///
		   1.post#1.treat0_balanced_${vat_freq}_1519 1.post#1.treat0_balanced_${vat_freq}_1419) coeflabel(1.post#1.treat0_balanced_${vat_freq}_1419 "Pre-Tax Profits")  ///
		   postfoot(\bottomrule) stats(N n_firms firm_fe year_industry_fe, labels("\# Observations" "\# Firms" "Firm FE?" "Year-Industry-Size FE?") fmt(%12.0fc %12.0fc))		
   

/*******************************************************************************	
 2. Robustness checks for VAT outcomes using Athey & Imbens (2006) estimator
*******************************************************************************/	

	* TWFE Estimator: INVESTMENT
	cap est drop *
	foreach var of varlist ppe_gross2 ppe_net2 inv_gross2 inv_net2 prob_inv_gross prob_inv_net {
		eststo: reghdfe `var'_n_0_${isr_since}${isr_to}_w95 post##treat0_${panel_isr}, a(id year#activity_sector#quantile0_${vat_freq}_${isr_since}${isr_to}) cluster(id)
	}
	
	esttab using "$tables/investment_robustness3.tex", replace booktabs noobs nolines f se(2) b(3) star(* 0.10 ** 0.05 *** 0.01) ///
		   keep(1.post#1.treat*) coeflabels(1.post#1.treat0_${panel_isr} "TWFE estimator") ///
		   mtitles("Gross PPE" "Net PPE" "Gross Investment" "Net Investment" "Pr(Gross investment = 1)" "Pr(Net investment = 1)")	
		      
	* CiC Estimator: INVESTMENT
	cap est drop *
	foreach var of varlist ppe_gross2 ppe_net2 inv_gross2 inv_net2 prob_inv_gross prob_inv_net {
		summ `var'_n_0_${isr_since}${isr_to}_w95 if year == 2016
		loc mean_dv = `r(mean)'

		if (`var' == prob_inv_gross | `var' == prob_inv_net) {
			eststo: cic dci `var'_n_0_${isr_since}${isr_to}_w95 treat0_${panel_isr} post, vce(bootstrap, reps(50)) 
			estadd scalar mean_dv `mean_dv'
		}
		else {
			eststo: cic continuous `var'_n_0_${isr_since}${isr_to}_w95 treat0_${panel_isr} post, vce(bootstrap, reps(50)) 
			estadd scalar mean_dv `mean_dv'
		}
	}
	
	esttab using "$tables/investment_robustness3.tex", append booktabs nonumbers nomtitles f se(2) b(3) star(* 0.10 ** 0.05 *** 0.01) ///
		   keep(mean) coeflabels(mean "CiC estimator") stats(N mean_dv, labels(Observations "Mean Dep Var 2016") fmt(%12.0fc %12.2fc)) postfoot(\bottomrule) 


		   
	* TWFE Estimator: CASH, WAGES, AND PROFITS
	cap est drop *
	foreach var of varlist cash_stock labor_costs pre_tax_profits after_tax_profits {
		eststo: reghdfe `var'_n_0_${isr_since}${isr_to}_w95 post##treat0_${panel_isr}, a(id year#activity_sector#quantile0_${vat_freq}_${isr_since}${isr_to}) cluster(id)
	}
	
	esttab using "$tables/performance_robustness3.tex", replace booktabs noobs nolines f se(2) b(3) star(* 0.10 ** 0.05 *** 0.01) ///
		   keep(1.post#1.treat*) coeflabels(1.post#1.treat0_${panel_isr} "TWFE estimator") ///
		   mtitles("Cash" "Wage Bill" "Pre-Tax Profits" "After-Tax Profits")
		   
	* CiC Estimator: CASH, WAGES, AND PROFITS
	cap est drop *
	foreach var of varlist cash_stock labor_costs pre_tax_profits after_tax_profits {
		summ `var'_n_0_${isr_since}${isr_to}_w95 if year == 2016
		loc mean_dv = `r(mean)'
		eststo: cic continuous `var'_n_0_${isr_since}${isr_to}_w95 treat0_${panel_isr} post, vce(bootstrap, reps(50)) 
		estadd scalar mean_dv `mean_dv'
	}
	
	esttab using "$tables/performance_robustness3.tex", append booktabs nonumbers nomtitles f se(2) b(3) star(* 0.10 ** 0.05 *** 0.01) ///
		   keep(mean) coeflabels(mean "CiC estimator") stats(N mean_dv, labels(Observations "Mean Dep Var 2016") fmt(%12.0fc %12.2fc)) postfoot(\bottomrule) 
		   
		   
		   
		   
