/*==============================================================================
Name: 		 6b_Robustness_ISV.do

Description: Conducts robustness checks running regression models on different
			 samples and alternative winsorizing using VAT outcomes. 
			 Produces table A2 and A4. 

Input: 	     ISV_reform_panel_quarter.dta
			 firmlevel_TreatStatus.dta
			 heterogeneity_traits.dta
			 Annual_sales.dta
			 
Output: 	 vat_robustness1.tex
			 vat_robustness3.tex
==============================================================================*/


/*******************************************************************************	
 1. Import VAT records and prepare dataset for manipulation
*******************************************************************************/

* Run program for import data and prepare it before analysis
	import_vat_data
	
	
	
/*******************************************************************************	
 2. Table 9 with robustness checks for VAT outcomes changing balancedness and
    winsorized at different thresholds
*******************************************************************************/	

* Notice that dummy_unrefunded only changes across sample, not winsorizing.
* This is because is a probability (taking values of 1 or 0), no need to winsorize.

	cap est drop *
	local balance 1518 1519 1418 1419
	
	foreach b of local balance {
		di in red "Regressions for withholding, sample `b'"
		eststo: qui reghdfe withholding_n_0_`b'_w95  post##treat0_balanced_${vat_freq}_`b', a(id quarter#activity_sector#quantile0_${vat_freq}_`b') cluster(id)
		eststo: qui reghdfe withholding_n_0_`b'_w99  post##treat0_balanced_${vat_freq}_`b', a(id quarter#activity_sector#quantile1_${vat_freq}_`b') cluster(id)
		eststo: qui reghdfe withholding_n_0_`b'_w999 post##treat0_balanced_${vat_freq}_`b', a(id quarter#activity_sector#quantile1_${vat_freq}_`b') cluster(id)
	}
	
	esttab using "$tables/vat_robustness1.tex", replace booktabs noobs f se(2) b(3) keep(1.post#1.treat0*)  star(* 0.10 ** 0.05 *** 0.01) 												   ///
		   rename(1.post#1.treat0_balanced_${vat_freq}_1519 1.post#1.treat0_balanced_${vat_freq}_1518 1.post#1.treat0_balanced_${vat_freq}_1418 1.post#1.treat0_balanced_${vat_freq}_1518  ///
		   1.post#1.treat0_balanced_${vat_freq}_1419 1.post#1.treat0_balanced_${vat_freq}_1518) coeflabel(1.post#1.treat0_balanced_${vat_freq}_1518 "Total Ammount Withheld")			   ///
		   mgroups("Balanced 2015q1 - 2018q4" "Balanced 2015q1 - 2019q4" "Balanced 2014q1 - 2018q4" "Balanced 2014q1 - 2019q4", span prefix(\multicolumn{@span}{c}{) suffix(}) 			   ///
		   pattern(1 0 0  1 0 0  1 0 0  1 0 0) erepeat(\cmidrule(lr){@span})) mtitles("95th" "99th" "99.9th" "95th" "99th" "99.9th" "95th" "99th" "99.9th" "95th" "99th" "99.9th")

	cap est drop *
	foreach var of varlist tax_total etr dummy_unrefunded {
					   	
		local lab: variable label `var'
		
		foreach b of local balance {
			di in red "Regressions for `var', sample `b'"
			eststo: qui reghdfe `var'_n_0_`b'_w95  post##treat0_balanced_${vat_freq}_`b', a(id quarter#activity_sector#quantile0_${vat_freq}_`b') cluster(id)
			eststo: qui reghdfe `var'_n_0_`b'_w99  post##treat0_balanced_${vat_freq}_`b', a(id quarter#activity_sector#quantile0_${vat_freq}_`b') cluster(id)
			eststo: qui reghdfe `var'_n_0_`b'_w999 post##treat0_balanced_${vat_freq}_`b', a(id quarter#activity_sector#quantile0_${vat_freq}_`b') cluster(id)					
		}
	
		esttab using "$tables/vat_robustness1.tex", append booktabs nonumbers nomtitles noobs nolines f se(2) b(3) keep(1.post#1.treat0*) 													   ///
			   rename(1.post#1.treat0_balanced_${vat_freq}_1519 1.post#1.treat0_balanced_${vat_freq}_1518 1.post#1.treat0_balanced_${vat_freq}_1418 1.post#1.treat0_balanced_${vat_freq}_1518  ///
			   1.post#1.treat0_balanced_${vat_freq}_1419 1.post#1.treat0_balanced_${vat_freq}_1518) coeflabel(1.post#1.treat0_balanced_${vat_freq}_1518 "`lab'") star(* 0.10 ** 0.05 *** 0.01)	
			   
		cap est drop *
	}
	
	foreach b of local balance {
		di in red "Regressions for unrefunded balance, sample `b'"
		eststo: qui reghdfe unref_balance_n_0_`b'_w95 post##treat0_balanced_${vat_freq}_`b', a(id quarter#activity_sector#quantile0_${vat_freq}_`b') cluster(id)
		estadd scalar n_firms = e(N_clust)
		estadd loc firm_fe "Yes"
		estadd loc quarter_industry_fe "Yes"
				
		eststo: qui reghdfe unref_balance_n_0_`b'_w99 post##treat0_balanced_${vat_freq}_`b', a(id quarter#activity_sector#quantile0_${vat_freq}_`b') cluster(id)
		estadd scalar n_firms = e(N_clust)
		estadd loc firm_fe "Yes"
		estadd loc quarter_industry_fe "Yes"
				
		eststo: qui reghdfe unref_balance_n_0_`b'_w999 post##treat0_balanced_${vat_freq}_`b', a(id quarter#activity_sector#quantile0_${vat_freq}_`b') cluster(id)
		estadd scalar n_firms = e(N_clust)
		estadd loc firm_fe "Yes"
		estadd loc quarter_industry_fe "Yes"			
	}
	
	esttab using "$tables/vat_robustness1.tex", append booktabs nonumbers nomtitles noobs f se(2) b(3) keep(1.post#1.treat0*) star(* 0.10 ** 0.05 *** 0.01) 							   ///
		   rename(1.post#1.treat0_balanced_${vat_freq}_1519 1.post#1.treat0_balanced_${vat_freq}_1518 1.post#1.treat0_balanced_${vat_freq}_1418 1.post#1.treat0_balanced_${vat_freq}_1518  ///
		   1.post#1.treat0_balanced_${vat_freq}_1419 1.post#1.treat0_balanced_${vat_freq}_1518) coeflabel(1.post#1.treat0_balanced_${vat_freq}_1518 "Stock Unrefunded Balance") ///				
		   stats(N n_firms firm_fe quarter_industry_fe, labels("\# Observations" "\# Firms" "Firm FE?" "Quarter-Industry-Size FE?") fmt(%12.0fc %12.0fc)) postfoot(\bottomrule)
	
	
/*******************************************************************************	
 2. Robustness checks for VAT outcomes using Athey & Imbens (2006) estimator
*******************************************************************************/	

	* TWFE Estimator
	cap est drop *
	foreach var of varlist $var_compliance1 {
		di in red "Baseline estimates: `var'"
		eststo: reghdfe `var'_n_0_${vat_since}${vat_to}_w95 post##treat0_${panel_vat}, a(id quarter#activity_sector#quantile0_${vat_freq}_${vat_since}${vat_to}) cluster(id)
	}
	
	esttab using "$tables/vat_robustness3.tex", replace booktabs noobs nolines f se(2) b(3) star(* 0.10 ** 0.05 *** 0.01) ///
		   keep(1.post#1.treat*) coeflabels(1.post#1.treat0_${panel_vat} "TWFE estimator") ///
		   mtitles("Digital Pay Withholding" "Remitted taxes" "Effective tax rate" "Pr(Unrefunded Balance = 1)" "Stock unrefunded balance")	
	

	* CiC Estimator
	cap est drop *
	foreach var of varlist $var_compliance1 {
		di in red "CIC (Athey and Imbens) estimates: `var'"
		summ `var'_n_0_${vat_since}${vat_to}_w95 if year == 2016
		loc mean_dv = `r(mean)'
		
		if inlist("`var'", "dummy_unrefunded") {
			eststo: cic dci `var'_n_0_${vat_since}${vat_to}_w95 treat0_${panel_vat} post, vce(bootstrap, reps(50)) 
			estadd scalar mean_dv `mean_dv'		
		}
		else {
			eststo: cic continuous `var'_n_0_${vat_since}${vat_to}_w95 treat0_${panel_vat} post, vce(bootstrap, reps(50)) 
			estadd scalar mean_dv `mean_dv'					
		}
	}
	
	esttab using "$tables/vat_robustness3.tex", append booktabs nonumbers nomtitles f se(2) b(3) star(* 0.10 ** 0.05 *** 0.01) ///
		   keep(mean) coeflabels(mean "CiC estimator") stats(N mean_dv, labels(Observations "Mean Dep Var 2016") fmt(%12.0fc %12.2fc)) postfoot(\bottomrule) 
	
