/*=============================================================================
Name: 		 6c_Robustness_ISR_Treat.do

Description: Conducts robustness checks for balance sheet outcomes changing the baseline 
			 definition of treatment and control groups. Produces figure A18.

Input: 	     ISR_reform_panel.dta
			 firmlevel_TreatStatus.dta
			 heterogeneity_traits.dta
			 Annual_sales.dta
			 
Output: 	 performance_robustness2.tex
			 did3_after_tax_profits.pdf
			 did3_pre_tax_profits.pdf
			 did3_labor_costs.pdf
			 did3_cash_stock.pdf
			 did3_prob_inv_net.pdf
			 did3_prob_inv_gross.pdf
			 did3_inv_net2.pdf
			 did3_inv_gross2.pdf
			 did3_ppe_net2.pdf
			 did3_ppe_gross2.pdf
			 did3_noncurrent_liab.pdf
			 did3_current_liab.pdf
			 did3_noncurrent_assets.pdf
			 did3_current_assets.pdf
			 did3_deduction.pdf
==============================================================================*/


/*******************************************************************************	
 1. Import income tax records and prepare dataset for manipulation
*******************************************************************************/
	
* Run program for import data and prepare it before analysis
	import_incometax_data

	
/*******************************************************************************	
 3. Figures 18 with dynamic DiD estimations using different T&C groups
*******************************************************************************/	
	
* Now we compare baseline estimates against three additional definition of T&C groups
* Only 2014-2019, and outcomes winsorized at the 95th fraction of observations, as we do in baseline estimations 
	
	cap est drop * 
	foreach var of varlist $var_balance $var_investment $var_performance {
		
		 local lab: variable label `var'
	
		 forvalues i = 0/3 {
			di in red "Regressions for treatment `i', variable `var'"
			gen treat = treat`i'_balanced_${vat_freq}_${isr_since}${isr_to} 
			eststo m`i': qui reghdfe `var'_n_`i'_${isr_since}${isr_to}_w95 ib0.treat##ib2016.year, a(id year#activity_sector#quantile`i'_${vat_freq}_${isr_since}${isr_to}) cluster(id)		
			drop treat
		 }
		 
		coefplot (m0, keep(1.treat*#*year*) baselevels omitted label("Baseline: [DCC>p75|DCC=1] vs [DCC<p25|DCC=1]") ///
				 lw(thin) msymbol(S) mcolor(black) ciopts(recast(rcap) lcolor(black*.3))) ///
				 (m1, keep(1.treat*#*year*) baselevels omitted label("[DCC>=p50|DCC=1] vs [DCC<p50|DCC=1]") ///
				 lw(thin) msymbol(O) mcolor(blue) ciopts(recast(rcap) lcolor(blue*.3)) offset(-0.3)) ///
				 (m2, keep(1.treat*#*year*) baselevels omitted label("[DCC=1|Withholding=1] vs [DCC=0|Withholding=1]") ///
				 lw(thin) msymbol(D) mcolor(orange) ciopts(recast(rcap) lcolor(orange*.3)) offset(-0.2)) ///
				 (m3, keep(1.treat*#*year*) baselevels omitted label("[DCC=1|Withholding=1] vs [DCC=0|Withholding=0]") ///
				 lw(thin) msymbol(T) mcolor(green) ciopts(recast(rcap) lcolor(green*.3)) offset(-0.1)), ///
				 yline(0, lc(black) lw(thin)) omitted vertical baselevels nolabels $graphopt ///
				 coeflabel(1.treat#2014.year = "2014" 1.treat#2015.year = "2015" 1.treat#2016.year = "2016" ///
				 1.treat#2017.year = "2017" 1.treat#2018.year = "2018" 1.treat#2019.year = "2019", labsize(small) angle(45)) ///
				 ytitle("Coef: `lab'") yscale(titlegap(3)) xline(3.5, lp(dash) lw(thin) lc(black)) legend(size(vsmall)) ylabel(, angle(0))
				 graph export "$figures/did3_`var'.pdf", replace
	}	
	
	
	
