/*==============================================================================
Name: 		 6d_Heterogeneity_ISR.do

Description: Run conditional DiD for heterogeneity analysis. 
			 Produces figures 9, A21, and A22.

Input: 	     ISR_reform_panel.dta
			 firmlevel_TreatStatus.dta
			 heterogeneity_traits.dta
			 Annual_sales.dta
			 
Output: 	 het1_after_tax_profits.pdf
			 het1_pre_tax_profits.pdf
			 het1_labor_costs.pdf
			 het1_cash_stock.pdf
			 het1_prob_inv_net.pdf
			 het1_prob_inv_gross.pdf
			 het1_inv_net2.pdf
			 het1_inv_gross2.pdf
			 het1_ppe_net2.pdf
			 het1_ppe_gross2.pdf
			 het1_noncurrent_liab.pdf
			 het1_current_liab.pdf
			 het1_noncurrent_assets.pdf
			 het1_current_assets.pdf
			 het1_deduction.pdf
==============================================================================*/


/*******************************************************************************	
 1. Import income tax records and prepare dataset for manipulation
*******************************************************************************/
	
* Run program for import data and prepare it before analysis
	import_incometax_data
	
* Let's keep only firms in baseline sample 
	keep if treat0_${panel_isr} != . & inrange(year, 20${isr_since}, 20${isr_to})
	
* Rename outcomes for simplicity
	rename low_cash_${vat_freq}_${isr_since}${isr_to} 		   low_cash
	rename capital_intensive_${vat_freq}_${isr_since}${isr_to} capital_intensive
	rename quantile0_${vat_freq}_${isr_since}${isr_to} 		   quantile_pre_reform


	
/*******************************************************************************	
 2. $figures 14, 15, and 16 with triple DiD for firm heterogeneity
*******************************************************************************/

cap est drop *
foreach var of varlist $var_balance $var_investment $var_performance {
	
	* Labels
	local lab: variable label `var'
	 if inlist("`var'", "noncurrent_assets", "prob_inv_net", "prob_inv_gross") {
        global xlab_grid "xlabel(-0.15(0.05)0.15)"
    }
    else if inlist("`var'", "after_tax_profits", "pre_tax_profits", "inv_net2") {
        global xlab_grid "xlabel(-0.04(0.02)0.04)"
    }
	else if inlist("`var'", "labor_costs", "cash_stock", "inv_gross2") {
		global xlab_grid "xlabel(-0.06(0.02)0.06)"
	}
	else if inlist("`var'", "current_assets") {
		global xlab_grid "xlabel(-0.2(0.05)0.2)"
	}
	
	* Regressions
	eststo m0:  qui reghdfe `var'_n_0_${isr_since}${isr_to}_w95 post##treat0_${panel_isr}, 				  					  a(id year#activity_sector#quantile_pre_reform) cluster(id)
	eststo m1:  qui reghdfe `var'_n_0_${isr_since}${isr_to}_w95 post##treat0_${panel_isr} if low_cash == 1, 				  a(id year#activity_sector#quantile_pre_reform) cluster(id)
	eststo m2:  qui reghdfe `var'_n_0_${isr_since}${isr_to}_w95 post##treat0_${panel_isr} if low_cash == 0, 				  a(id year#activity_sector#quantile_pre_reform) cluster(id)
	eststo m3:  qui reghdfe `var'_n_0_${isr_since}${isr_to}_w95 post##treat0_${panel_isr} if inlist(quantile_pre_reform,1,2), a(id year#activity_sector#quantile_pre_reform) cluster(id) 
	eststo m4: 	qui reghdfe `var'_n_0_${isr_since}${isr_to}_w95 post##treat0_${panel_isr} if inlist(quantile_pre_reform,3,4), a(id year#activity_sector#quantile_pre_reform) cluster(id)
	eststo m5:  qui reghdfe `var'_n_0_${isr_since}${isr_to}_w95 post##treat0_${panel_isr} if net_below_median == 1, 		  a(id year#activity_sector#quantile_pre_reform) cluster(id)
	eststo m6:  qui reghdfe `var'_n_0_${isr_since}${isr_to}_w95 post##treat0_${panel_isr} if net_below_median == 0,   		  a(id year#activity_sector#quantile_pre_reform) cluster(id)
	eststo m7:  qui reghdfe `var'_n_0_${isr_since}${isr_to}_w95 post##treat0_${panel_isr} if capital_intensive == 0, 		  a(id year#activity_sector#quantile_pre_reform) cluster(id)
	eststo m8:  qui reghdfe `var'_n_0_${isr_since}${isr_to}_w95 post##treat0_${panel_isr} if capital_intensive == 1,   		  a(id year#activity_sector#quantile_pre_reform) cluster(id)
	eststo m9:  qui reghdfe `var'_n_0_${isr_since}${isr_to}_w95 post##treat0_${panel_isr} if manufacturing == 1,   			  a(id year#activity_sector#quantile_pre_reform) cluster(id)
	eststo m10: qui reghdfe `var'_n_0_${isr_since}${isr_to}_w95 post##treat0_${panel_isr} if manufacturing == 0,	    	  a(id year#activity_sector#quantile_pre_reform) cluster(id)
	
	* Figures
	coefplot m0 || m1 || m2 || m3 || m4 || m5 || m6 || m7 || m8 || m9 || m10, keep(1.post#1.treat0_${panel_isr}) ${graphopt} ///
			 xline(0, lcolor(black) lp(dash)) mcolor(blue%70) ciopts(lcolor(gs8%70) recast(rcap)) legend(off) grid(none)     ///
			 headings(2="{bf:Cash}" 4="{bf:Firm size}" 6="{bf:Value-added}" 8="{bf:Capital}" 10="{bf:Industry}") 		     ///
			 bycoefs bylabels("All" "Low liquidity" "High liquidity"  "Below median size" "Above median size" 				 ///
			 "Low value-added" "High value-added" "Low capital intensity" "High capital intensity" "Manufacturing" "Other") ${xlab_grid}
	graph export "$figures/het1_`var'.pdf", replace
}

