/*==============================================================================
Name: 		 6d_Heterogeneity_ISV.do

Description: Run conditional DiD for heterogeneity analysis. Produces figures 8, 
			 A19, and A20.

Input: 	     ISV_reform_panel_quarter.dta
			 firmlevel_TreatStatus.dta
			 Annual_sales.dta
			 heterogeneity_traits.dta
			 
Output: 	 het1_value_added.pdf
			 het1_tax_total.pdf
			 het1_etr.pdf
			 het1_dummy_unrefunded.pdf
			 het1_unref_balance.pdf
			 het1_revenue.pdf
			 het1_tax_sales.pdf
			 het1_purchases.pdf
			 het1_tax_purchases.pdf
			 het1_exem_purchases.pdf
			 het1_withholding_cards.pdf
			 het1_withholding.pdf
==============================================================================*/

	
/*******************************************************************************	
 1. Import VAT records and prepare dataset for manipulation
*******************************************************************************/
	
* Run program for import data and prepare it before analysis
	import_vat_data
	
* Let's keep only firms in baseline sample 
	keep if treat0_${panel_vat} != . & inrange(year, 20${vat_since}, 20${vat_to})
	
* Rename outcomes for simplicity
	rename low_cash_${vat_freq}_${vat_since}${vat_to} 		   low_cash
	rename capital_intensive_${vat_freq}_${vat_since}${vat_to} capital_intensive
	rename quantile0_${vat_freq}_${vat_since}${vat_to} 		   quantile_pre_reform


/*******************************************************************************	
 2. $figures 12 and 13 with triple DiD for firm heterogeneity
*******************************************************************************/
 
cap est drop *
foreach var of varlist $var_compliance $var_outcomes {

	
	* Labels
	local lab: variable label `var'
	 if inlist("`var'", "value_added", "tax_purchases",  "purchases", "tax_sales", "revenue") {
        global xlab_grid "xlabel(-0.15(0.05)0.15)"
    }
    else if inlist("`var'", "unref_balance", "exem_purchases", "etr", "tax_total", "withholding_cards",  "withholding") {
        global xlab_grid "xlabel(-0.04(0.01)0.005)"
    }
	else if inlist("`var'", "dummy_unrefunded") {
        global xlab_grid "xlabel(-0.15(0.05)0.05)"
    }
		
	* Regressions
	eststo m0:  qui reghdfe `var'_n_0_${vat_since}${vat_to}_w95 post##treat0_${panel_vat}, 				  					  a(id quarter#activity_sector#quantile_pre_reform) cluster(id)
	eststo m1:  qui reghdfe `var'_n_0_${vat_since}${vat_to}_w95 post##treat0_${panel_vat} if low_cash == 1, 				  a(id quarter#activity_sector#quantile_pre_reform) cluster(id)
	eststo m2:  qui reghdfe `var'_n_0_${vat_since}${vat_to}_w95 post##treat0_${panel_vat} if low_cash == 0, 				  a(id quarter#activity_sector#quantile_pre_reform) cluster(id)
	eststo m3:  qui reghdfe `var'_n_0_${vat_since}${vat_to}_w95 post##treat0_${panel_vat} if inlist(quantile_pre_reform,1,2), a(id quarter#activity_sector#quantile_pre_reform) cluster(id) 
	eststo m4: 	qui reghdfe `var'_n_0_${vat_since}${vat_to}_w95 post##treat0_${panel_vat} if inlist(quantile_pre_reform,3,4), a(id quarter#activity_sector#quantile_pre_reform) cluster(id)
	eststo m5:  qui reghdfe `var'_n_0_${vat_since}${vat_to}_w95 post##treat0_${panel_vat} if net_below_median == 1, 		  a(id quarter#activity_sector#quantile_pre_reform) cluster(id)
	eststo m6:  qui reghdfe `var'_n_0_${vat_since}${vat_to}_w95 post##treat0_${panel_vat} if net_below_median == 0,   		  a(id quarter#activity_sector#quantile_pre_reform) cluster(id)
	eststo m7:  qui reghdfe `var'_n_0_${vat_since}${vat_to}_w95 post##treat0_${panel_vat} if capital_intensive == 0, 		  a(id quarter#activity_sector#quantile_pre_reform) cluster(id)
	eststo m8:  qui reghdfe `var'_n_0_${vat_since}${vat_to}_w95 post##treat0_${panel_vat} if capital_intensive == 1,   		  a(id quarter#activity_sector#quantile_pre_reform) cluster(id)
	eststo m9:  qui reghdfe `var'_n_0_${vat_since}${vat_to}_w95 post##treat0_${panel_vat} if manufacturing == 1,   			  a(id quarter#activity_sector#quantile_pre_reform) cluster(id)
	eststo m10: qui reghdfe `var'_n_0_${vat_since}${vat_to}_w95 post##treat0_${panel_vat} if manufacturing == 0,	    	  a(id quarter#activity_sector#quantile_pre_reform) cluster(id)
	
	* Figures
	coefplot m0 || m1 || m2 || m3 || m4 || m5 || m6 || m7 || m8 || m9 || m10, keep(1.post#1.treat0_${panel_vat}) ${graphopt} ///
			 xline(0, lcolor(black) lp(dash)) mcolor(blue%70) ciopts(lcolor(gs8%70) recast(rcap)) legend(off) grid(none)     ///
			 headings(2="{bf:Cash}" 4="{bf:Firm size}" 6="{bf:Value-added}" 8="{bf:Capital}" 10="{bf:Industry}") 		     ///
			 bycoefs bylabels("All" "Low liquidity" "High liquidity"  "Below median size" "Above median size" 				 ///
			 "Low value-added" "High value-added" "Low capital intensity" "High capital intensity" "Manufacturing" "Other") ${xlab_grid}
	graph export "$figures/het1_`var'.pdf", replace
}

